@@ -28,149 +28,21 @@
 
 
 void
-SetupLele(CoordsArray *cdsA)
+SetupLele(CdsArray *cdsA)
 {
     int             i;
 
     /* set up matrices and initialize for Lele distmat covariance calculations */
     for (i = 0; i < cdsA->cnum; ++i)
-        cdsA->coords[i]->innerprod = MatAlloc(cdsA->vlen, cdsA->vlen);
+        cdsA->cds[i]->innerprod = MatAlloc(cdsA->vlen, cdsA->vlen);
 
-    cdsA->avecoords->innerprod = MatAlloc(cdsA->vlen, cdsA->vlen);
+    cdsA->avecds->innerprod = MatAlloc(cdsA->vlen, cdsA->vlen);
     DistMatsAlloc(cdsA);
 }
 
 
 void
-CovInvLAPACK(CoordsArray *cdsA)
-{
-    int                      i, j;
-    int                 info = 0;
-    char                     upper = 'U';
-    int                 vlen = (int) cdsA->vlen;
-    double                 **tmpmat = NULL;
-
-    tmpmat = MatAlloc(cdsA->vlen, cdsA->vlen);
-    for (i = 0; i < cdsA->vlen; ++i)
-    {
-        tmpmat[i][i] = cdsA->CovMat[i][i];
-        for (j = 0; j < i; ++j)
-            tmpmat[j][i] = tmpmat[i][j] = cdsA->CovMat[i][j];
-    }
-
-    /* normalize the CovMat */
-    /*MatPrint(cdsA->CovMat, cdsA->vlen);*/
-    NormalizeCovMat(tmpmat, cdsA->vlen);
-
-    /* LAPACK dpotrf and dpotri compute the inverse using cholesky decomposition */
-    DPOTRF(&upper, &vlen, &tmpmat[0][0], &vlen, &info);
-
-    if (info == 0)
-        DPOTRI(&upper, &vlen, &tmpmat[0][0], &vlen, &info);
-    else if (info > 0)
-    {
-        fprintf(stderr,
-                " \n\n LAPACK dpotrf Choleski decomposition of covariance matrix choked; \n");
-        fprintf(stderr,
-                "           leading minor of order %d is not positive definite \n", info);
-        fprintf(stderr,
-                "           using LAPACK dsytrf/dsytri instead \n");
-        CovInvIndefLAPACK(cdsA);
-        return;
-    }
-
-    /* copy lower to upper to WtMat*/
-    for (i = 0; i < cdsA->vlen; ++i)
-    {
-        cdsA->WtMat[i][i] = tmpmat[i][i];
-        SCREAMF(cdsA->WtMat[i][i]);
-        for (j = 0; j < i; ++j)
-            cdsA->WtMat[j][i] = cdsA->WtMat[i][j] = tmpmat[i][j];
-    }
-
-    MatDestroy(&tmpmat);
-    /*MatPrint(cdsA->WtMat, cdsA->vlen);*/
-    /*SCREAMS("LAPACK");*/
-}
-
-
-/* this will invert an indefinite covariance matrix */
-void
-CovInvIndefLAPACK(CoordsArray *cdsA)
-{
-    int                      i, j;
-    int                 info = 0;
-    char                     upper = 'U';
-    int                 vlen = (int) cdsA->vlen;
-    int                 lwork;
-    int                *ipiv;
-    double                  *work = NULL;
-    double                  *w = NULL;
-
-    w = (double *) malloc(vlen * sizeof(double));
-    work = (double *) malloc(sizeof(double));
-    ipiv = (int *) malloc(vlen * sizeof(int));
-
-    lwork = -1;
- 
-    /* normalize the CovMat */
-    /*MatPrint(cdsA->CovMat, cdsA->vlen);*/
-    NormalizeCovMat(cdsA->CovMat, cdsA->vlen);
-    DSYTRF(&upper, &vlen, &cdsA->Dij_matrix[0][0], &vlen, ipiv, work, &lwork, &info);
-
-    if (info < 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR120: the %d-th argument had an illegal value \n\n", info);
-        exit(EXIT_FAILURE);
-    }
-    else if (info > 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR120: D(%d, %d) is exactly zero; matrix is singular \n\n", info, info);
-        exit(EXIT_FAILURE);
-    }
-
-    lwork = (int) work[0];
-    free(work);
-    work = (double *) malloc(lwork * sizeof(double));
-    DSYTRF(&upper, &vlen, &cdsA->Dij_matrix[0][0], &vlen, ipiv, work, &lwork, &info);
-    free(work);
-    work = (double *) malloc(vlen * sizeof(double));
-    DSYTRI(&upper, &vlen, &cdsA->Dij_matrix[0][0], &vlen, ipiv, work, &info);
-
-    if (info > 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR121: D(%d, %d) is exactly zero; matrix is singular \n\n", info, info);
-        exit(EXIT_FAILURE);
-    }
-    else if (info < 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR121: the %d-th argument had an illegal value \n\n", info);
-        exit(EXIT_FAILURE);
-    }
-
-    /* copy lower to upper to WtMat*/
-    for (i = 0; i < cdsA->vlen; ++i)
-    {
-        cdsA->WtMat[i][i] = cdsA->CovMat[i][i];
-        SCREAMF(cdsA->WtMat[i][i]);
-        for (j = 0; j < i; ++j)
-            cdsA->WtMat[j][i] = cdsA->WtMat[i][j] = cdsA->CovMat[i][j];
-    }
-
-    free(ipiv);
-    free(w);
-    free(work);
-    /*MatPrint(cdsA->WtMat, cdsA->vlen);*/
-    SCREAMS("dsytrf/dsytri LAPACK");
-}
-
-
-void
-CalcLeleCovMat(CoordsArray *cdsA)
+CalcLeleCovMat(CdsArray *cdsA)
 {
     double        **MMT = NULL;
     double          idf, cov_sum;
@@ -181,9 +53,9 @@ CalcLeleCovMat(CoordsArray *cdsA)
     idf = 1.0 / (3.0 * (double)(cdsA->cnum)); /* ML, biased, maybe should be n-1 to be unbiased?? */
 
     for (i = 0; i < cdsA->cnum; ++i)
-        CoordsInnerProd(cdsA->coords[i]);
+        CdsInnerProd(cdsA->cds[i]);
 
-    CoordsInnerProd(cdsA->avecoords);
+    CdsInnerProd(cdsA->avecds);
 
     for (i = 0; i < cdsA->vlen; ++i)
     {
@@ -191,7 +63,7 @@ CalcLeleCovMat(CoordsArray *cdsA)
         {
             cov_sum = 0.0;
             for (k = 0; k < cdsA->cnum; ++k)
-                cov_sum += (cdsA->coords[k]->innerprod[i][j] - cdsA->avecoords->innerprod[i][j]);
+                cov_sum += (cdsA->cds[k]->innerprod[i][j] - cdsA->avecds->innerprod[i][j]);
 
             cdsA->CovMat[i][j] = cov_sum * idf;
         }
@@ -230,14 +102,14 @@ CalcLeleCovMat(CoordsArray *cdsA)
 
 /* caller must find average structure first */
 void
-CalcLeleVariances(CoordsArray *cdsA)
+CalcLeleVariances(CdsArray *cdsA)
 {
     double          idf;
     double         *var = cdsA->var;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    const double   *avex = (const double *) cdsA->avecoords->x,
-                   *avey = (const double *) cdsA->avecoords->y,
-                   *avez = (const double *) cdsA->avecoords->z;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    const double   *avex = (const double *) cdsA->avecds->x,
+                   *avey = (const double *) cdsA->avecds->y,
+                   *avez = (const double *) cdsA->avecds->z;
 
     int             i, j;
 
@@ -248,9 +120,9 @@ CalcLeleVariances(CoordsArray *cdsA)
         var[i] = 0.0;
         for (j = 0; j < cdsA->cnum; ++j)
         {
-            var[i] += coords[j]->x[i] * coords[j]->x[i]
-                    + coords[j]->y[i] * coords[j]->y[i]
-                    + coords[j]->z[i] * coords[j]->z[i];
+            var[i] += cds[j]->x[i] * cds[j]->x[i]
+                    + cds[j]->y[i] * cds[j]->y[i]
+                    + cds[j]->z[i] * cds[j]->z[i];
         }
 
         var[i] *= idf;
@@ -265,47 +137,47 @@ CalcLeleVariances(CoordsArray *cdsA)
 
 
 void
-NNxCoords(double **mat, Coords *coords)
+NNxCds(double **mat, Cds *cds)
 {
     int             i, k;
 
     /* (i x k)(k x j) = (i x j) */
     /* (N x N)(N x 3) = (N x 3) */
-    for (i = 0; i < coords->vlen; ++i)
+    for (i = 0; i < cds->vlen; ++i)
     {
-        coords->covx[i] = coords->covy[i] = coords->covz[i] = 0.0;
-        for (k = 0; k < coords->vlen; ++k)
+        cds->covx[i] = cds->covy[i] = cds->covz[i] = 0.0;
+        for (k = 0; k < cds->vlen; ++k)
         {
-            coords->covx[i] += (mat[i][k] * coords->x[k]);
-            coords->covy[i] += (mat[i][k] * coords->y[k]);
-            coords->covz[i] += (mat[i][k] * coords->z[k]);
+            cds->covx[i] += (mat[i][k] * cds->x[k]);
+            cds->covy[i] += (mat[i][k] * cds->y[k]);
+            cds->covz[i] += (mat[i][k] * cds->z[k]);
         }
     }
 }
 
 
 void
-CoordsxNN(Coords *coords, const double **mat)
+CdsxNN(Cds *cds, const double **mat)
 {
     int             j, k;
 
     /* (i x k)(k x j) = (i x j) */
     /* (3 x N)(N x N) = (3 x N) */
-    for (j = 0; j < coords->vlen; ++j)
+    for (j = 0; j < cds->vlen; ++j)
     {
-        coords->covx[j] = coords->covy[j] = coords->covz[j] = 0.0;
-        for (k = 0; k < coords->vlen; ++k)
+        cds->covx[j] = cds->covy[j] = cds->covz[j] = 0.0;
+        for (k = 0; k < cds->vlen; ++k)
         {
-            coords->covx[j] += (coords->x[k] * mat[k][j]);
-            coords->covy[j] += (coords->y[k] * mat[k][j]);
-            coords->covz[j] += (coords->z[k] * mat[k][j]);
+            cds->covx[j] += (cds->x[k] * mat[k][j]);
+            cds->covy[j] += (cds->y[k] * mat[k][j]);
+            cds->covz[j] += (cds->z[k] * mat[k][j]);
         }
     }
 }
 
 
 /*  double
-    RadGyrSqr(Coords *coords)
+    RadGyrSqr(Cds *cds)
 
     computes the unweighted square of the unaveraged radius of gyration
     of a molecule basically the sum of the square of the distances of 
@@ -313,44 +185,44 @@ CoordsxNN(Coords *coords, const double **mat)
     been centered)
 */
 double
-RadGyrSqr(const Coords *coords)
+RadGyrSqr(const Cds *cds)
 {
     int             i;
     double          sum = 0.0;
 
-    for (i = 0; i < coords->vlen; ++i)
-        sum += (mysquare(coords->x[i]) + mysquare(coords->y[i]) + mysquare(coords->z[i]));
+    for (i = 0; i < cds->vlen; ++i)
+        sum += (mysquare(cds->x[i]) + mysquare(cds->y[i]) + mysquare(cds->z[i]));
 
     return(sum);
 }
 
 
 double
-RadGyrSqrW(const Coords *coords, const double *weights)
+RadGyrSqrW(const Cds *cds, const double *weights)
 {
     int             i;
     double          sum = 0.0;
 
-    for (i = 0; i < coords->vlen; ++i)
-        sum += weights[i] * (mysquare(coords->x[i]) + mysquare(coords->y[i]) + mysquare(coords->z[i]));
+    for (i = 0; i < cds->vlen; ++i)
+        sum += weights[i] * (mysquare(cds->x[i]) + mysquare(cds->y[i]) + mysquare(cds->z[i]));
 
     return(sum);
 }
 
 
 double
-RadGyrSqrCov(Coords *coords, const double **weightmat)
+RadGyrSqrCov(Cds *cds, const double **weightmat)
 {
     int             i;
     double          sum = 0.0;
 
-    CoordsxNN(coords, weightmat);
+    CdsxNN(cds, weightmat);
 
-    for (i = 0; i < coords->vlen; ++i)
+    for (i = 0; i < cds->vlen; ++i)
     {
-        sum += (coords->covx[i] * coords->x[i]) +
-               (coords->covy[i] * coords->y[i]) +
-               (coords->covz[i] * coords->z[i]);
+        sum += (cds->covx[i] * cds->x[i]) +
+               (cds->covy[i] * cds->y[i]) +
+               (cds->covz[i] * cds->z[i]);
     }
 
     return(sum);
@@ -358,56 +230,56 @@ RadGyrSqrCov(Coords *coords, const double **weightmat)
 
 
 void
-CoordsInnerProd(Coords *coords)
+CdsInnerProd(Cds *cds)
 {
     /* (i x k)(k x j) = (i x j) */
     /* (N x 3)(3 x N) = (N x N) */
     int             i, j;
-    double        **innerprod = coords->innerprod;
+    double        **innerprod = cds->innerprod;
 
-    for (i = 0; i < coords->vlen; ++i)
-        for (j = 0; j < coords->vlen; ++j)
-            coords->innerprod[i][j] = 0.0;
+    for (i = 0; i < cds->vlen; ++i)
+        for (j = 0; j < cds->vlen; ++j)
+            cds->innerprod[i][j] = 0.0;
 
-    for (i = 0; i < coords->vlen; ++i)
+    for (i = 0; i < cds->vlen; ++i)
     {
         for (j = 0; j <= i; ++j)
         {
-            innerprod[i][j] += (coords->x[i] * coords->x[j])
-                             + (coords->y[i] * coords->y[j])
-                             + (coords->z[i] * coords->z[j]);
+            innerprod[i][j] += (cds->x[i] * cds->x[j])
+                             + (cds->y[i] * cds->y[j])
+                             + (cds->z[i] * cds->z[j]);
         }
     }
 
-    for (i = 0; i < coords->vlen; ++i)
+    for (i = 0; i < cds->vlen; ++i)
         for (j = 0; j < i; ++j)
-            coords->innerprod[j][i] = coords->innerprod[i][j];
+            cds->innerprod[j][i] = cds->innerprod[i][j];
 }
 
 
 void
-CoordsInnerProd2(Coords *coords)
+CdsInnerProd2(Cds *cds)
 {
     /* (i x k)(k x j) = (i x j) */
     /* (3 x N)(N x 3) = (3 x 3) */
     int             k;
     double        **innerprod2 = NULL;
-    const double   *x = (const double *) coords->x,
-                   *y = (const double *) coords->y,
-                   *z = (const double *) coords->z;
+    const double   *x = (const double *) cds->x,
+                   *y = (const double *) cds->y,
+                   *z = (const double *) cds->z;
     double          xk, yk, zk;
 
-    if (coords->innerprod2 == NULL)
+    if (cds->innerprod2 == NULL)
     {
-        innerprod2 = coords->innerprod2 = MatAlloc(3, 3);
+        innerprod2 = cds->innerprod2 = MatAlloc(3, 3);
     }
     else
     {
-        innerprod2 = coords->innerprod2;
+        innerprod2 = cds->innerprod2;
         memset(&innerprod2[0][0], 0, 9 * sizeof(double));
     }
 
-    for (k = 0; k < coords->vlen; ++k)
+    for (k = 0; k < cds->vlen; ++k)
     {
         xk = x[k];
         yk = y[k];
@@ -425,7 +297,7 @@ CoordsInnerProd2(Coords *coords)
     innerprod2[2][0] = innerprod2[0][2];
     innerprod2[2][1] = innerprod2[1][2];
 
-    /* Mat3Print(coords->innerprod2); */
+    /* Mat3Print(cds->innerprod2); */
 }
 
 
@@ -477,12 +349,12 @@ MatInnerProdSymOp(double **mato, const double **mati, const int N)
 }
 
 
-/*  Calculates EDMA average of distance coords, with chi^2 variance correction for
-    bias. This is an unbiased estimate of the average coords, *assuming that the 
-    coords are distributed normally*. 
+/*  Calculates EDMA average of distance cds, with chi^2 variance correction for
+    bias. This is an unbiased estimate of the average cds, *assuming that the 
+    cds are distributed normally*. 
 */
 void
-CalcEDMADistMat(CoordsArray *cdsA)
+CalcEDMADistMat(CdsArray *cdsA)
 {
     int             i, j, k;
     const int       len = cdsA->vlen;
@@ -509,13 +381,13 @@ CalcEDMADistMat(CoordsArray *cdsA)
     /* Lele, Subhash (1993) "Euclidean Distance Matrix Analysis (EDMA): Estimation of mean form */
     /* and mean form difference." Mathematical Geology 25(5):573-602 */
 
-    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Coords i */
+    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Cds i */
     for (i = 0; i < cdsA->cnum; ++i)
         for (j = 0; j < len; ++j)
             for (k = 0; k < j; ++k)
-                cdsA->distmat->matrix[i][j][k] = SqrCoordsDist(cdsA->coords[i], j, cdsA->coords[i], k);
+                cdsA->distmat->matrix[i][j][k] = SqrCdsDist(cdsA->cds[i], j, cdsA->cds[i], k);
 
-    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CoordsArray */
+    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CdsArray */
     for (i = 0; i < len; ++i)
         for (j = 0; j < i; ++j)
             distmat[i][j] = 0.0;
@@ -576,7 +448,7 @@ CalcEDMADistMat(CoordsArray *cdsA)
 
 
 void
-CalcEDMADistMatOcc(CoordsArray *cdsA)
+CalcEDMADistMatOcc(CdsArray *cdsA)
 {
     int             i, j, k;
     const int       len = cdsA->vlen, cnum = cdsA->cnum;
@@ -602,13 +474,13 @@ CalcEDMADistMatOcc(CoordsArray *cdsA)
     /* Lele, Subhash (1993) "Euclidean Distance Matrix Analysis (EDMA): Estimation of mean form */
     /* and mean form difference." Mathematical Geology 25(5):573-602 */
 
-    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Coords i */
+    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Cds i */
     for (i = 0; i < cnum; ++i)
         for (j = 0; j < len; ++j)
             for (k = 0; k < j; ++k)
-                cdsA->distmat->matrix[i][j][k] = SqrCoordsDist(cdsA->coords[i], j, cdsA->coords[i], k);
+                cdsA->distmat->matrix[i][j][k] = SqrCdsDist(cdsA->cds[i], j, cdsA->cds[i], k);
 
-    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CoordsArray */
+    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CdsArray */
     for (j = 0; j < len; ++j)
     {
         for (k = 0; k < j; ++k)
@@ -617,7 +489,7 @@ CalcEDMADistMatOcc(CoordsArray *cdsA)
             occsum = 0.0;
             for (i = 0; i < cnum; ++i)
             {
-                occ = cdsA->coords[i]->o[j] * cdsA->coords[i]->o[k];
+                occ = cdsA->cds[i]->o[j] * cdsA->cds[i]->o[k];
                 occsum += occ;
                 cdsA->Dij_matrix[j][k] += occ * cdsA->distmat->matrix[i][j][k];
             }
@@ -643,7 +515,7 @@ CalcEDMADistMatOcc(CoordsArray *cdsA)
             occsum = 0.0;
             for (i = 0; i < cnum; ++i)
             {
-                occ = cdsA->coords[i]->o[j] * cdsA->coords[i]->o[k];
+                occ = cdsA->cds[i]->o[j] * cdsA->cds[i]->o[k];
                 occsum += occ;
                 cdsA->Var_matrix[j][k] += occ * mysquare(cdsA->distmat->matrix[i][j][k] - distmat[j][k]);
             }
@@ -701,7 +573,7 @@ LeleCenterMat(double **mat, const int len)
     /* on_diagonal = 1.0 + off_diagonal; */
     tmpmat = MatAlloc(len, len);
 
-    memcpy(&tmpmat[0][0], &mat[0][0], len*len*sizeof(double));
+    memcpy(tmpmat[0], mat[0], len*len*sizeof(double));
 
 	for (i = 0; i < len; ++i)
 	{
@@ -717,7 +589,7 @@ LeleCenterMat(double **mat, const int len)
 
     /* MatPrint(tmpmat, len); */
 
-    memcpy(&mat[0][0], &tmpmat[0][0], len*len*sizeof(double));
+    memcpy(mat[0], tmpmat[0], len*len*sizeof(double));
 
 	for (i = 0; i < len; ++i)
 	{
@@ -775,40 +647,40 @@ DoubleCenterMat(double **mat, const int len)
 }
 
 
-/*  Calculates straight average of distance coords, without X^2 variance
+/*  Calculates straight average of distance cds, without X^2 variance
     correction like CalcEDMADistMat() does. This is a biased estimate of
-    the average coords (the squared distances between two coords are too
+    the average cds (the squared distances between two cds are too
     large by the sum of the variance for each coord), but I believe it is
     maximum likelihood of some sort.
  */
 void
-CalcMLDistMat(CoordsArray *cdsA)
+CalcMLDistMat(CdsArray *cdsA)
 {
     int             i, j, k;
     const int       len = cdsA->vlen;
     double          normalize, tmpx, tmpy, tmpz;
     double        **Dij_matrix = cdsA->Dij_matrix;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    const Coords   *coordsi;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    const Cds   *cdsi;
 
     normalize = 1.0 / cdsA->cnum;
 
-    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Coords i */
-    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CoordsArray */
+    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Cds i */
+    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CdsArray */
     for (i = 0; i < len; ++i)
         for (j = 0; j < i; ++j)
             Dij_matrix[i][j] = 0.0;
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        coordsi = coords[i];
+        cdsi = cds[i];
         for (j = 0; j < len; ++j)
         {
             for (k = 0; k < j; ++k)
             {
-                tmpx = coordsi->x[j] - coordsi->x[k];
-                tmpy = coordsi->y[j] - coordsi->y[k];
-                tmpz = coordsi->z[j] - coordsi->z[k];
+                tmpx = cdsi->x[j] - cdsi->x[k];
+                tmpy = cdsi->y[j] - cdsi->y[k];
+                tmpz = cdsi->z[j] - cdsi->z[k];
 
                 Dij_matrix[j][k] += (tmpx*tmpx + tmpy*tmpy + tmpz*tmpz);
             }
@@ -829,18 +701,18 @@ CalcMLDistMat(CoordsArray *cdsA)
 
 /* Same as CalcMLDistMat(), but weight by occupancy */
 void
-CalcMLDistMatOcc(CoordsArray *cdsA)
+CalcMLDistMatOcc(CdsArray *cdsA)
 {
     int             i, j, k, m;
     const int       len = cdsA->vlen;
     const int       cnum = cdsA->cnum;
     double          occsum, occ, tmpx, tmpy, tmpz;
     double        **Dij_matrix = cdsA->Dij_matrix;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    const Coords   *coordsi;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    const Cds   *cdsi;
 
-    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Coords i */
-    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CoordsArray */
+    /* (1) calculate the symmetric j x k atom squared distance e^i(l,m) matrix for all structure Cds i */
+    /* (2) calculate the average squared distance matrix ave{e(l,m)} for the CdsArray */
     for (j = 0; j < len; ++j)
     {
         for (k = 0; k < j; ++k)
@@ -849,12 +721,12 @@ CalcMLDistMatOcc(CoordsArray *cdsA)
             occsum = 0.0;
             for (i = 0; i < cnum; ++i)
             {
-                coordsi = coords[i];
-                occ = coordsi->o[j] * coordsi->o[k];
+                cdsi = cds[i];
+                occ = cdsi->o[j] * cdsi->o[k];
                 occsum += occ;
-                tmpx = coordsi->x[j] - coordsi->x[k];
-                tmpy = coordsi->y[j] - coordsi->y[k];
-                tmpz = coordsi->z[j] - coordsi->z[k];
+                tmpx = cdsi->x[j] - cdsi->x[k];
+                tmpy = cdsi->y[j] - cdsi->y[k];
+                tmpz = cdsi->z[j] - cdsi->z[k];
 
                 Dij_matrix[j][k] += occ * (tmpx*tmpx + tmpy*tmpy + tmpz*tmpz);
             }
@@ -899,8 +771,258 @@ CalcMLDistMatOcc(CoordsArray *cdsA)
 }
 
 
+static double
+InnerProduct(double *A, Cds *cds1, Cds *cds2, const int len, const double *weight)
+{
+    double          x1, x2, y1, y2, z1, z2;
+    int             i;
+    const double   *fx1 = cds1->x, *fy1 = cds1->y, *fz1 = cds1->z;
+    const double   *fx2 = cds2->x, *fy2 = cds2->y, *fz2 = cds2->z;
+    double          G1 = 0.0, G2 = 0.0;
+    A[0] = A[1] = A[2] = A[3] = A[4] = A[5] = A[6] = A[7] = A[8] = 0.0;
+    if (weight != NULL)
+   {
+      for (i = 0; i < len; ++i)
+      {
+         x1 = weight[i] * fx1[i];
+         y1 = weight[i] * fy1[i];
+         z1 = weight[i] * fz1[i];
+
+         G1 += x1 * fx1[i] + y1 * fy1[i] + z1 * fz1[i];
+
+         x2 = fx2[i];
+         y2 = fy2[i];
+         z2 = fz2[i];
+
+         G2 += weight[i] * (x2 * x2 + y2 * y2 + z2 * z2);
+
+         A[0] +=  (x1 * x2);
+         A[1] +=  (x1 * y2);
+         A[2] +=  (x1 * z2);
+
+         A[3] +=  (y1 * x2);
+         A[4] +=  (y1 * y2);
+         A[5] +=  (y1 * z2);
+
+         A[6] +=  (z1 * x2);
+         A[7] +=  (z1 * y2);
+         A[8] +=  (z1 * z2);   
+      }
+   }
+   else
+   {
+      for (i = 0; i < len; ++i)
+      {
+         x1 = fx1[i];
+         y1 = fy1[i];
+         z1 = fz1[i];
+
+         G1 += x1 * x1 + y1 * y1 + z1 * z1;
+
+         x2 = fx2[i];
+         y2 = fy2[i];
+         z2 = fz2[i];
+
+         G2 += (x2 * x2 + y2 * y2 + z2 * z2);
+
+         A[0] +=  (x1 * x2);
+         A[1] +=  (x1 * y2);
+         A[2] +=  (x1 * z2);
+
+         A[3] +=  (y1 * x2);
+         A[4] +=  (y1 * y2);
+         A[5] +=  (y1 * z2);
+
+         A[6] +=  (z1 * x2);
+         A[7] +=  (z1 * y2);
+         A[8] +=  (z1 * z2);  
+      }
+   }
+    return (G1 + G2) * 0.5;
+}
+
+
+static
+int FastCalcRMSDAndRotation(double *rot, double *A, double *msd, double E0, int len, double minScore)
+{
+   double          Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz;
+   double          Szz2, Syy2, Sxx2, Sxy2, Syz2, Sxz2, Syx2, Szy2, Szx2,
+                   SyzSzymSyySzz2, Sxx2Syy2Szz2Syz2Szy2, Sxy2Sxz2Syx2Szx2,
+                   SxzpSzx, SyzpSzy, SxypSyx, SyzmSzy,
+                   SxzmSzx, SxymSyx, SxxpSyy, SxxmSyy;
+   double          C[4];
+   int i;
+   double mxEigenV; 
+   double oldg = 0.0;
+   double b, a, delta, ms;
+   double q1, q2, q3, q4, normq;
+   double d11, d12, d13, d14, d21, d22, d23, d24;
+   double d31, d32, d33, d34, d41, d42, d43, d44;
+   double a2, x2, y2, z2; 
+   double xy, az, zx, ay, yz, ax; 
+   double d3344_4334, d3244_4234, d3243_4233, d3143_4133,d3144_4134, d3142_4132; 
+
+   Sxx = A[0]; Sxy = A[1]; Sxz = A[2];
+   Syx = A[3]; Syy = A[4]; Syz = A[5];
+   Szx = A[6]; Szy = A[7]; Szz = A[8];
+
+   Sxx2 = Sxx * Sxx;
+   Syy2 = Syy * Syy;
+   Szz2 = Szz * Szz;
+
+   Sxy2 = Sxy * Sxy;
+   Syz2 = Syz * Syz;
+   Sxz2 = Sxz * Sxz;
+
+   Syx2 = Syx * Syx;
+   Szy2 = Szy * Szy;
+   Szx2 = Szx * Szx;
+
+   SyzSzymSyySzz2 = 2.0*(Syz*Szy - Syy*Szz);
+   Sxx2Syy2Szz2Syz2Szy2 = Syy2 + Szz2 - Sxx2 + Syz2 + Szy2;
+
+   C[2] = -2.0 * (Sxx2 + Syy2 + Szz2 + Sxy2 + Syx2 + Sxz2 + Szx2 + Syz2 + Szy2);
+   C[1] = 8.0 * (Sxx*Syz*Szy + Syy*Szx*Sxz + Szz*Sxy*Syx - Sxx*Syy*Szz - Syz*Szx*Sxy - Szy*Syx*Sxz);
+
+   SxzpSzx = Sxz + Szx;
+   SyzpSzy = Syz + Szy;
+   SxypSyx = Sxy + Syx;
+   SyzmSzy = Syz - Szy;
+   SxzmSzx = Sxz - Szx;
+   SxymSyx = Sxy - Syx;
+   SxxpSyy = Sxx + Syy;
+   SxxmSyy = Sxx - Syy;
+   Sxy2Sxz2Syx2Szx2 = Sxy2 + Sxz2 - Syx2 - Szx2;
+
+   C[0] = Sxy2Sxz2Syx2Szx2 * Sxy2Sxz2Syx2Szx2
+          + (Sxx2Syy2Szz2Syz2Szy2 + SyzSzymSyySzz2) * (Sxx2Syy2Szz2Syz2Szy2 - SyzSzymSyySzz2)
+          + (-(SxzpSzx)*(SyzmSzy)+(SxymSyx)*(SxxmSyy-Szz)) * (-(SxzmSzx)*(SyzpSzy)+(SxymSyx)*(SxxmSyy+Szz))
+          + (-(SxzpSzx)*(SyzpSzy)-(SxypSyx)*(SxxpSyy-Szz)) * (-(SxzmSzx)*(SyzmSzy)-(SxypSyx)*(SxxpSyy+Szz))
+          + (+(SxypSyx)*(SyzpSzy)+(SxzpSzx)*(SxxmSyy+Szz)) * (-(SxymSyx)*(SyzmSzy)+(SxzpSzx)*(SxxpSyy+Szz))
+          + (+(SxypSyx)*(SyzmSzy)+(SxzmSzx)*(SxxmSyy-Szz)) * (-(SxymSyx)*(SyzpSzy)+(SxzmSzx)*(SxxpSyy-Szz));
+
+
+   mxEigenV = E0;
+   for (i = 0; i < 50; ++i)
+   {
+     oldg = mxEigenV;
+     x2 = mxEigenV*mxEigenV;
+     b = (x2 + C[2])*mxEigenV;
+     a = b + C[1];
+     delta = ((a*mxEigenV + C[0])/(2.0*x2*mxEigenV + b + a));
+     mxEigenV -= delta;
+     if (fabs(mxEigenV - oldg) < fabs((1e-6)*mxEigenV)) {
+       break;
+     }
+   }
+   if (i == 50) 
+   {
+      fprintf(stderr," more than %d iterations needed, something wrong!\b", i);
+   }
+
+   ms = 2.0 * (E0 - mxEigenV) / len;
+   (*msd) = ms;
+
+   if (minScore > 0) 
+   {
+        if (ms < minScore)
+        {
+            // Don't bother with rotation. 
+            return -1;
+        }   
+   }
+
+   d11 = SxxpSyy + Szz-mxEigenV; d12 = SyzmSzy; d13 = - SxzmSzx; d14 = SxymSyx;
+   d21 = SyzmSzy; d22 = SxxmSyy - Szz-mxEigenV; d23 = SxypSyx; d24= SxzpSzx;
+   d31 = d13; d32 = d23; d33 = Syy-Sxx-Szz - mxEigenV; d34 = SyzpSzy;
+   d41 = d14; d42 = d24; d43 = d34; d44 = Szz - SxxpSyy - mxEigenV;
+   d3344_4334 = d33 * d44 - d43 * d34; d3244_4234 = d32 * d44-d42*d34;
+   d3243_4233 = d32 * d43 - d42 * d33; d3143_4133 = d31 * d43-d41*d33;
+   d3144_4134 = d31 * d44 - d41 * d34; d3142_4132 = d31 * d42-d41*d32;
+   q1 =  d22*d3344_4334-d23*d3244_4234+d24*d3243_4233;
+   q2 = -d21*d3344_4334+d23*d3144_4134-d24*d3143_4133;
+   q3 =  d21*d3244_4234-d22*d3144_4134+d24*d3142_4132;
+   q4 = -d21*d3243_4233+d22*d3143_4133-d23*d3142_4132;
+
+   normq = sqrt(q1 * q1 + q2 * q2 + q3 * q3 + q4 * q4);
+   q1 /= normq; q2 /= normq; q3 /= normq; q4 /= normq;
+
+   a2 = q1 * q1;
+   x2 = q2 * q2;
+   y2 = q3 * q3;
+   z2 = q4 * q4;
+
+   xy = q2 * q3;
+   az = q1 * q4;
+   zx = q4 * q2;
+   ay = q1 * q3;
+   yz = q3 * q4;
+   ax = q1 * q2;
+
+   rot[0] = a2 + x2 - y2 - z2;
+   rot[1] = 2 * (xy + az);
+   rot[2] = 2 * (zx - ay);
+   rot[3] = 2 * (xy - az);
+   rot[4] = a2 - x2 + y2 - z2;
+   rot[5] = 2 * (yz + ax);
+   rot[6] = 2 * (zx + ay);
+   rot[7] = 2 * (yz - ax);
+   rot[8] = a2 - x2 - y2 + z2;
+
+   return 0;
+}
+
+
+/* static void  */
+/* CenterCds(Cds *cds, const int len) */
+/* { */
+/*     int             i; */
+/*     double          xsum, ysum, zsum; */
+/*     double         *x = cds->x, *y = cds->y, *z = cds->z; */
+/*  */
+/*     xsum = ysum = zsum = 0.0; */
+/*     for (i = 0; i < len; ++i) */
+/*     { */
+/*         xsum += x[i]; */
+/*         ysum += y[i]; */
+/*         zsum += z[i]; */
+/*     } */
+/*  */
+/*     xsum /= len; */
+/*     ysum /= len; */
+/*     zsum /= len; */
+/*  */
+/*     for (i = 0; i < len; ++i) */
+/*     { */
+/*         x[i] -= xsum; */
+/*         y[i] -= ysum; */
+/*         z[i] -= zsum; */
+/*     } */
+/* } */
+
+
+static double
+CalcRMSDRotationalMatrix(Cds *cds1, Cds *cds2, const int len, double *rot, const double *weight)
+{
+    double          A[9];
+    double          rmsd;
+
+    /* center the structures */
+    //CenterCds(cds1, len);
+    //CenterCds(cds2, len);
+
+    /* calculate the (weighted) inner product of two structures */
+    double E0 = InnerProduct(A, cds1, cds2, len, weight);
+
+    /* calculate the RMSD & rotational matrix */
+    FastCalcRMSDAndRotation(rot, A, &rmsd, E0, len, -1);
+
+    return rmsd;
+}
+
+
 /* Calculate the average coordinates from the average distance matrix
-   as calculated in CalcEDMADistMat(CoordsArray *cdsA) and
+   as calculated in CalcEDMADistMat(CdsArray *cdsA) and
    CalcMLDistMat. This is a distance geometry embedding algorithm.
    
    See:
@@ -920,26 +1042,16 @@ CalcMLDistMatOcc(CoordsArray *cdsA)
    are the x, y, and z coordinate vectors for the structure, respectively.   
 */
 void
-EmbedAveCoords(CoordsArray *cdsA)
+EmbedAveCds(CdsArray *cdsA)
 {  
     int            i;
-    int            info = 0;
-    char           jobz_v = 'V';
-    char           range_i = 'I';
-    char           uplo_u = 'U';
     int            vlen = cdsA->vlen;
-    int            il, iu, m;
-    double         vl, vu;
-    double         abstol;
     double         w0, w1, w2;
     double       **z = NULL;
-    int           *isuppz = NULL;
-    int           *iwork = NULL;
-    int            lwork, liwork, negone;
-    double        *work = NULL;
     double        *w = NULL;
     double         deviation1, deviation2;
-    Coords        *avecoords = cdsA->avecoords;
+    Cds        *avecds = cdsA->avecds;
+    Cds        *cds = cdsA->cds[0];
 
     /* Center/normalize with H, */
     /* B(M) = -0.5 * H{Eu(M)}H */
@@ -947,82 +1059,10 @@ EmbedAveCoords(CoordsArray *cdsA)
 
     DoubleCenterMat(cdsA->Dij_matrix, vlen);
 
-    negone = -1;
-    vl = vu = 0.0;
     w = (double *) calloc(vlen, sizeof(double));
-    il = vlen - 2;
-    iu = vlen - 0;
-    abstol = 0.0;
-    z = MatAlloc(3, vlen);
-    isuppz = (int *) calloc(6, sizeof(int));
-    work = (double *) calloc(1, sizeof(double));
-    iwork = (int *) calloc(1, sizeof(int));
+    z = MatAlloc(vlen, vlen);
 
-    /* first dsyevr call lwork and liwork = -1 which
-       makes dsyevr calculate optimum workspace given
-       the other params */
-    DSYEVR(&jobz_v, &range_i, &uplo_u,
-            &vlen, &cdsA->Dij_matrix[0][0], &vlen,
-            &vl, &vu, &il, &iu,
-            &abstol, &m, w, &z[0][0], &vlen, isuppz,
-            work, &negone, iwork, &negone, &info);
-
-    lwork = work[0];
-    liwork = iwork[0];
-
-/*     lwork = 26*vlen; */
-/*     liwork = 10*vlen; */
-
-    free(work);
-    free(iwork);
-    work = (double *) calloc(lwork, sizeof(double));
-    iwork = (int *) calloc(liwork, sizeof(int));
-
-    /* LAPACK dsyevr() computes selected eigenvalues, and optionally, eigenvectors of a
-       real symmetric matrix. Here we only need the first three largest evals and
-       corresponding evecs. */
-/*     jobz_v = 'V'; */
-/*     range_i = 'I'; */
-/*     uplo_u = 'U'; */
-/*     vlen = cdsA->vlen; */
-/*     vl = vu = 0.0; */
-/*     il = vlen - 2; */
-/*     iu = vlen - 0; */
-/*     abstol = 0.0; */
-/*     m = 0; */
-/*     w = (double *) calloc(vlen, sizeof(double)); */
-/*     z = MatAlloc(3, vlen); */
-/*     info = 0; */
-    DSYEVR(&jobz_v, &range_i, &uplo_u,
-            &vlen, &cdsA->Dij_matrix[0][0], &vlen,
-            &vl, &vu, &il, &iu,
-            &abstol, &m, w, &z[0][0], &vlen, isuppz,
-            work, &lwork, iwork, &liwork, &info);
-
-    if (info > 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR119: LAPACK dsyevr() complete eigenvalue/eigenvector solving choked; \n");
-        fprintf(stderr, "           the algorithm failed to converge; %d \n", info);
-        fprintf(stderr, "           off-diagonal elements of an intermediate tridiagonal \n");
-        fprintf(stderr, "           form did not converge to zero \n\n");
-        exit(EXIT_FAILURE);
-    }
-    else if (info < 0)
-    {
-        fprintf(stderr, "\n\n");
-        fprintf(stderr, " ERROR120: the %d-th argument had an illegal value \n\n", info);
-        exit(EXIT_FAILURE);
-    }
-
-/*     int j; */
-/*     for (i = 0; i < cdsA->vlen; ++i) */
-/*     { */
-/*         double bstick = 0.0; */
-/*         for (j = 1; j <= i; ++j) */
-/*             bstick += (1.0 / (double) j); */
-/*         printf("\n%f %f", w[i], bstick); */
-/*     } */
+    EigenGSLDest(cdsA->Dij_matrix, vlen, w, z, 1);
 
     w0 = sqrt(w[0]);
     w1 = sqrt(w[1]);
@@ -1030,53 +1070,45 @@ EmbedAveCoords(CoordsArray *cdsA)
 
     for (i = 0; i < cdsA->vlen; ++i)
     {
-        avecoords->x[i] = w2 * z[2][i];
-        avecoords->y[i] = w1 * z[1][i];
-        avecoords->z[i] = w0 * z[0][i];
-        avecoords->o[i] = 1.0;
+        avecds->x[i] = w2 * z[i][2];
+        avecds->y[i] = w1 * z[i][1];
+        avecds->z[i] = w0 * z[i][0];
+        avecds->o[i] = 1.0;
     }
 
-    /* WriteAveCoordsFile(cdsA, "test.pdb"); */
+    /* WriteAveCdsFile(cdsA, "test.pdb"); */
 
     /* check to see if the average structure has the wrong chirality,
        since embedding basically randomly reflects the structure */
-/*     deviation1 = Kearsley_unwt(cdsA->coords[0], */
-/*                                avecoords, */
-/*                                cdsA->coords[0]->matrix, */
-/*                                cdsA->coords[0]->evals); */
 
-    deviation1 = ProcLAPACKSVDvan(cdsA->coords[0],
-                                  avecoords,
-                                  cdsA->coords[0]->matrix,
-                                  cdsA->coords[0]->tmpmat3a,
-                                  cdsA->coords[0]->tmpmat3b,
-                                  cdsA->coords[0]->tmpmat3c,
-                                  cdsA->coords[0]->tmpvec3a);
+/*     deviation1 = ProcLAPACKSVDvan(cdsA->cds[0], */
+/*                                   avecds, */
+/*                                   cdsA->cds[0]->matrix, */
+/*                                   cdsA->cds[0]->tmpmat3a, */
+/*                                   cdsA->cds[0]->tmpmat3b, */
+/*                                   cdsA->cds[0]->tmpmat3c, */
+/*                                   cdsA->cds[0]->tmpvec3a); */
+
+    deviation1 = CalcRMSDRotationalMatrix(cds, avecds, cds->vlen, &cds->matrix[0][0], NULL);
 
     for (i = 0; i < cdsA->vlen; ++i)
-        avecoords->x[i] = -avecoords->x[i];
+        avecds->x[i] = -avecds->x[i];
 
-/*     deviation2 = Kearsley_unwt(cdsA->coords[0], */
-/*                                avecoords, */
-/*                                cdsA->coords[0]->matrix, */
-/*                                cdsA->coords[0]->evals); */
+/*     deviation2 = ProcLAPACKSVDvan(cdsA->cds[0], */
+/*                                   avecds, */
+/*                                   cdsA->cds[0]->matrix, */
+/*                                   cdsA->cds[0]->tmpmat3a, */
+/*                                   cdsA->cds[0]->tmpmat3b, */
+/*                                   cdsA->cds[0]->tmpmat3c, */
+/*                                   cdsA->cds[0]->tmpvec3a); */
 
-    deviation2 = ProcLAPACKSVDvan(cdsA->coords[0],
-                                  avecoords,
-                                  cdsA->coords[0]->matrix,
-                                  cdsA->coords[0]->tmpmat3a,
-                                  cdsA->coords[0]->tmpmat3b,
-                                  cdsA->coords[0]->tmpmat3c,
-                                  cdsA->coords[0]->tmpvec3a);
+    deviation2 = CalcRMSDRotationalMatrix(cds, avecds, cds->vlen, &cds->matrix[0][0], NULL);
 
     if (deviation1 < deviation2)
         for (i = 0; i < cdsA->vlen; ++i)
-            avecoords->x[i] = -avecoords->x[i];
+            avecds->x[i] = -avecds->x[i];
 
-    /* PrintCoords(cdsA->avecoords); */
-    free(work);
-    free(iwork);
+    /* PrintCds(cdsA->avecds); */
     free(w);
     MatDestroy(&z);
-    free(isuppz);
 }
