@@ -35,19 +35,19 @@
 #include "pdbStats.h"
 #include "pdbUtils.h"
 #include "pdbIO.h"
-#include "Coords.h"
+#include "Cds.h"
 #include "MultiPose.h"
-#include "PDBCoords.h"
+#include "PDBCds.h"
 #include "distfit.h"
 #include "DLTmath.h"
-#include "RandCoords.h"
+#include "RandCds.h"
 #include <gsl/gsl_sf_hyperg.h>
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_randist.h>
 
 
 static double
-CalcLogLGibbs(CoordsArray *cdsA);
+CalcLogLGibbs(CdsArray *cdsA);
 
 double
 scale_met3(const double n, const double gamma, const double phi, const double x, const gsl_rng *r2, double loc, double width);
@@ -159,15 +159,15 @@ ExpectScale(const double n, const double gamma, const double phi)
 
 
 static void
-AveCds(CoordsArray *cdsA)
+AveCdsGibbs(CdsArray *cdsA)
 {
     int             i, j;
-    double         *avex = cdsA->avecoords->x,
-                   *avey = cdsA->avecoords->y,
-                   *avez = cdsA->avecoords->z;
+    double         *avex = cdsA->avecds->x,
+                   *avey = cdsA->avecds->y,
+                   *avez = cdsA->avecds->z;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    Coords         *coordsj = NULL;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    Cds         *cdsj = NULL;
     double          invcnum = 1.0 / (double) cnum;
 
     memset(avex, 0, vlen * sizeof(double));
@@ -176,13 +176,13 @@ AveCds(CoordsArray *cdsA)
 
     for (j = 0; j < cnum; ++j)
     {
-        coordsj = (Coords *) coords[j];
+        cdsj = (Cds *) cds[j];
 
         for (i = 0; i < vlen; ++i)
         {
-            avex[i] += coordsj->x[i];
-            avey[i] += coordsj->y[i];
-            avez[i] += coordsj->z[i];
+            avex[i] += cdsj->x[i];
+            avey[i] += cdsj->y[i];
+            avez[i] += cdsj->z[i];
         }
     }
 
@@ -247,25 +247,25 @@ RotMatToQuaternion(const double **rot, double *quat)
 
 
 static void
-CdsInnProd2(Coords *coords, const double *wts)
+CdsInnProd2(Cds *cds, const double *wts)
 {
     /* (i x k)(k x j) = (i x j) */
     /* (3 x N)(N x 3) = (3 x 3) */
     int             k;
     double        **innerprod2 = NULL;
-    const double   *x = (const double *) coords->x,
-                   *y = (const double *) coords->y,
-                   *z = (const double *) coords->z;
+    const double   *x = (const double *) cds->x,
+                   *y = (const double *) cds->y,
+                   *z = (const double *) cds->z;
     double          xk, yk, zk, wtsi;
 
-    if (coords->innerprod2 == NULL)
-        innerprod2 = coords->innerprod2 = MatAlloc(3, 3);
+    if (cds->innerprod2 == NULL)
+        innerprod2 = cds->innerprod2 = MatAlloc(3, 3);
     else
-        innerprod2 = coords->innerprod2;
+        innerprod2 = cds->innerprod2;
 
     memset(&innerprod2[0][0], 0, 9 * sizeof(double));
 
-    for (k = 0; k < coords->vlen; ++k)
+    for (k = 0; k < cds->vlen; ++k)
     {
         wtsi = wts[k];
 
@@ -292,21 +292,21 @@ CdsInnProd2(Coords *coords, const double *wts)
 
 
 static void
-CalcCdsPrincAxes(Coords *coords, double **rotmat, const double *wts)
+CalcCdsPrincAxesGibbs(Cds *cds, double **rotmat, const double *wts)
 {
     double         *evals = (double *) malloc(3 * sizeof(double));
     double          det;
     int             i, j;
 
-    CdsInnProd2(coords, wts);
-    jacobi3_cyc(coords->innerprod2, evals, rotmat, 1e-8);
-//     eigensym((const double **) coords->innerprod2, evals, rotmat, 3);
+    CdsInnProd2(cds, wts);
+    jacobi3_cyc(cds->innerprod2, evals, rotmat, 1e-8);
+//     eigensym((const double **) cds->innerprod2, evals, rotmat, 3);
 //     Mat3TransposeIp(rotmat);
     EigenSort3b(rotmat, evals);
 //    printf("\nevals:\n");
     //Mat3TransposeIp(rotmat);
 //    VecPrint(evals, 3);
-//    printf("\nCalcCoordsPrincAxes A:");
+//    printf("\nCalcCdsPrincAxes A:");
 //    Mat3Print(rotmat);
 
     det = Mat3Det((const double **) rotmat);
@@ -520,7 +520,7 @@ invgamma_dev4(const double b, const double c, const gsl_rng *r2)
 
 
 static void
-VarCds(CoordsArray *cdsA)
+VarCds(CdsArray *cdsA)
 {
     int             i, j;
     double          sqrdist;
@@ -528,11 +528,11 @@ VarCds(CoordsArray *cdsA)
     double          variance;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double         *var = cdsA->var;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    Coords         *coordsj = NULL;
-    const double   *avex = (const double *) cdsA->avecoords->x,
-                   *avey = (const double *) cdsA->avecoords->y,
-                   *avez = (const double *) cdsA->avecoords->z;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    Cds         *cdsj = NULL;
+    const double   *avex = (const double *) cdsA->avecds->x,
+                   *avey = (const double *) cdsA->avecds->y,
+                   *avez = (const double *) cdsA->avecds->z;
 
     variance = 0.0;
     for (i = 0; i < vlen; ++i)
@@ -540,10 +540,10 @@ VarCds(CoordsArray *cdsA)
         sqrdist = 0.0;
         for (j = 0; j < cnum; ++j)
         {
-            coordsj = (Coords *) coords[j];
-            tmpx = coordsj->x[i] - avex[i];
-            tmpy = coordsj->y[i] - avey[i];
-            tmpz = coordsj->z[i] - avez[i];
+            cdsj = (Cds *) cds[j];
+            tmpx = cdsj->x[i] - avex[i];
+            tmpy = cdsj->y[i] - avey[i];
+            tmpz = cdsj->z[i] - avez[i];
             sqrdist += tmpx*tmpx + tmpy*tmpy + tmpz*tmpz;
         }
 
@@ -558,14 +558,14 @@ VarCds(CoordsArray *cdsA)
 
 
 static void
-MetScale(CoordsArray *cdsA, const gsl_rng *r2)
+MetScale(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const int       n = 3.0 * vlen + 1.0;
     double          phi, gamma;
-    Coords         *cdsi = NULL;
-    Coords         *avecds = cdsA->avecoords;
+    Cds         *cdsi = NULL;
+    Cds         *avecds = cdsA->avecds;
     double          sm, width, oldscale;
     double          var = cdsA->stats->var;
     int             skip = 7;
@@ -573,20 +573,20 @@ MetScale(CoordsArray *cdsA, const gsl_rng *r2)
 
     double sum = 0.0;
     for (i = 0; i < cnum; ++i)
-        sum += cdsA->coords[i]->scale;
+        sum += cdsA->cds[i]->scale;
 
     sum /= cnum;
     printf("\nave: % f", sum);
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = cdsA->coords[i];
+        cdsi = cdsA->cds[i];
         oldscale = cdsi->scale;
 
         /* here we have to undo the effects of the previous scaling step, for both phi and gamma
            phi is the self inner prod, so the scale is squared */
-        phi = TrCoordsInnerProd(cdsi, vlen) / (var * oldscale * oldscale);
-        gamma = TrCoordsInnerProd2(cdsi, avecds, vlen) / (var * oldscale) - priorg;
+        phi = TrCdsInnerProd(cdsi, vlen) / (var * oldscale * oldscale);
+        gamma = TrCdsInnerProd2(cdsi, avecds, vlen) / (var * oldscale) - priorg;
         sm = ScaleMax(n, gamma, phi);
         width = sqrt(1.0 / (phi + (n-1.0)/(sm*sm)));
 
@@ -595,7 +595,7 @@ MetScale(CoordsArray *cdsA, const gsl_rng *r2)
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
         cdsi->scale = scale_log_met3(n, gamma, phi, oldscale, r2, sm, width, skip);
-        ScaleCoords(cdsi, cdsi->scale / oldscale);
+        ScaleCds(cdsi, cdsi->scale / oldscale);
 
         printf("\nscale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
         fflush(NULL);
@@ -604,14 +604,14 @@ MetScale(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-MetScaleDiag(CoordsArray *cdsA, const gsl_rng *r2)
+MetScaleDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const int       n = 3.0 * vlen + 1.0;
     double          phi, gamma;
-    Coords         *cdsi = NULL;
-    Coords         *avecds = cdsA->avecoords;
+    Cds         *cdsi = NULL;
+    Cds         *avecds = cdsA->avecds;
     double         *wts = cdsA->w;
     double          sm, width, oldscale;
     int             skip = 7;
@@ -619,27 +619,27 @@ MetScaleDiag(CoordsArray *cdsA, const gsl_rng *r2)
 
     double sum = 0.0;
     for (i = 0; i < cnum; ++i)
-        sum += cdsA->coords[i]->scale;
+        sum += cdsA->cds[i]->scale;
 
     sum /= cnum;
     printf("\nave: % f", sum);
 
     sum = 0.0;
     for (i = 0; i < cnum; ++i)
-        sum += log(cdsA->coords[i]->scale);
+        sum += log(cdsA->cds[i]->scale);
 
     sum /= cnum;
     printf("\nave log: % f", sum);
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = cdsA->coords[i];
+        cdsi = cdsA->cds[i];
         oldscale = cdsi->scale;
 
         /* here we have to undo the effects of the previous scaling step, for both phi and gamma
            phi is the self inner prod, so the scale is squared */
-        phi = TrCoordsInnerProdWt(cdsi, vlen, wts) / (oldscale * oldscale);
-        gamma = TrCoordsInnerProdWt2(cdsi, avecds, vlen, wts) / oldscale - priorg;
+        phi = TrCdsInnerProdWt(cdsi, vlen, wts) / (oldscale * oldscale);
+        gamma = TrCdsInnerProdWt2(cdsi, avecds, vlen, wts) / oldscale - priorg;
         sm = ScaleMax(n, gamma, phi);
         width = sqrt(1.0 / (phi + (n-1.0)/(sm*sm)));
 
@@ -648,7 +648,7 @@ MetScaleDiag(CoordsArray *cdsA, const gsl_rng *r2)
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
         cdsi->scale = scale_log_met3(n, gamma, phi, oldscale, r2, sm, width, skip);
-        ScaleCoords(cdsi, cdsi->scale / oldscale);
+        ScaleCds(cdsi, cdsi->scale / oldscale);
 
         printf("\n(diag) scale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
         fflush(NULL);
@@ -657,7 +657,7 @@ MetScaleDiag(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsVar(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsVar(CdsArray *cdsA, const gsl_rng *r2)
 {
     double          var;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
@@ -674,7 +674,7 @@ GibbsVar(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsPhi(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsPhi(CdsArray *cdsA, const gsl_rng *r2)
 {
     const int       vlen = cdsA->vlen;
     double          invtr, a, b;
@@ -695,7 +695,7 @@ GibbsPhi(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsVarDiag(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsVarDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     double          phi = cdsA->stats->phi;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
@@ -717,18 +717,18 @@ GibbsVarDiag(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsMean(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsMean(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
-    double         *avex = cdsA->avecoords->x,
-                   *avey = cdsA->avecoords->y,
-                   *avez = cdsA->avecoords->z;
+    double         *avex = cdsA->avecds->x,
+                   *avey = cdsA->avecds->y,
+                   *avez = cdsA->avecds->z;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          mvar = sqrt(cdsA->stats->var / cnum);
 
 /*     printf("\nmvar: % e", mvar); */
 
-    AveCds(cdsA);
+    AveCdsGibbs(cdsA);
 
     for (i = 0; i < vlen; ++i)
     {
@@ -737,26 +737,26 @@ GibbsMean(CoordsArray *cdsA, const gsl_rng *r2)
         avez[i] += gsl_ran_gaussian(r2, mvar);
     }
 
-    CenMass(cdsA->avecoords);
-    ApplyCenterIp(cdsA->avecoords);
+    CenMass(cdsA->avecds);
+    ApplyCenterIp(cdsA->avecds);
 
     for (i = 0; i < cnum; ++i)
-        NegTransCoordsIp(cdsA->coords[i], cdsA->avecoords->center);
+        NegTransCdsIp(cdsA->cds[i], cdsA->avecds->center);
 }
 
 
 static void
-GibbsMeanDiag(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsMeanDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
-    Coords         *avecds = cdsA->avecoords;
+    Cds         *avecds = cdsA->avecds;
     double         *avex = avecds->x,
                    *avey = avecds->y,
                    *avez = avecds->z;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          mvar;
 
-    AveCds(cdsA);
+    AveCdsGibbs(cdsA);
 
     for (i = 0; i < vlen; ++i)
     {
@@ -772,7 +772,7 @@ GibbsMeanDiag(CoordsArray *cdsA, const gsl_rng *r2)
     ApplyCenterIp(avecds);
 
     for (i = 0; i < cnum; ++i)
-        NegTransCoordsIp(cdsA->coords[i], cdsA->avecoords->center);
+        NegTransCdsIp(cdsA->cds[i], cdsA->avecds->center);
 
 //    printf("\nmean trans[%d]: % f % f % f", i+1, 
 //           avecds->center[0], avecds->center[1], avecds->center[2]);
@@ -781,47 +781,47 @@ GibbsMeanDiag(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsMeanWrite(CoordsArray *cdsA, const gsl_rng *r2, const int iter)
+GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
     int             i;
-    Coords         *avecds = cdsA->avecoords;
+    Cds         *avecds = cdsA->avecds;
     const int       vlen = cdsA->vlen, cnum = cdsA->cnum;
     char            filename[256];
 
     for (i = 0; i < vlen; ++i)
         cdsA->w[i] = 1.0 / cdsA->stats->var;
 
-//    AveCds(cdsA);
+//    AveCdsGibbs(cdsA);
     GibbsMean(cdsA, r2);
 // 
 //     CenMass(avecds);
 //     ApplyCenterIp(avecds);
 
-    CalcCdsPrincAxes(avecds, avecds->matrix, cdsA->w);
+    CalcCdsPrincAxesGibbs(avecds, avecds->matrix, cdsA->w);
     Mat3TransposeIp(avecds->matrix);
-    RotateCoordsIp(avecds, (const double **) avecds->matrix);
+    RotateCdsIp(avecds, (const double **) avecds->matrix);
 
     for (i = 0; i < cnum; ++i)
-        RotateCoordsIp(cdsA->coords[i], (const double **) avecds->matrix);
+        RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
 
     sprintf(filename, "%s%05d.pdb", "gibbs_", iter);
 /*     printf("\nWriting %s", filename); */
 /*     fflush(NULL); */
-    WriteTheseusCoordsModelFile(cdsA, filename);
+    WriteTheseusCdsModelFile(cdsA, filename);
 
     GibbsMean(cdsA, r2);
 }
 
 
 static void
-GibbsMeanDiagWrite(CoordsArray *cdsA, const gsl_rng *r2, const int iter)
+GibbsMeanDiagWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
     int             i;
-    Coords         *avecds = cdsA->avecoords;
+    Cds         *avecds = cdsA->avecds;
     const int       vlen = cdsA->vlen, cnum = cdsA->cnum;
     char            filename[256];
 
-    //AveCds(cdsA);
+    //AveCdsGibbs(cdsA);
     GibbsMeanDiag(cdsA, r2);
 
     for (i = 0; i < vlen; ++i)
@@ -831,12 +831,12 @@ GibbsMeanDiagWrite(CoordsArray *cdsA, const gsl_rng *r2, const int iter)
 //     CenMassWtIp(avecds, cdsA->w);
 //     ApplyCenterIp(avecds);
 
-    CalcCdsPrincAxes(avecds, avecds->matrix, cdsA->w);
+    CalcCdsPrincAxesGibbs(avecds, avecds->matrix, cdsA->w);
     Mat3TransposeIp(avecds->matrix);
-    RotateCoordsIp(avecds, (const double **) avecds->matrix);
+    RotateCdsIp(avecds, (const double **) avecds->matrix);
 
     for (i = 0; i < cnum; ++i)
-        RotateCoordsIp(cdsA->coords[i], (const double **) avecds->matrix);
+        RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
 
 //     for (i = 0; i < vlen; ++i)
 //         cdsA->w[i] = 1.0 / cdsA->var[i];
@@ -844,27 +844,27 @@ GibbsMeanDiagWrite(CoordsArray *cdsA, const gsl_rng *r2, const int iter)
     sprintf(filename, "%s%05d.pdb", "gibbs_", iter);
 /*     printf("\nWriting %s", filename); */
 /*     fflush(NULL); */
-    WriteTheseusCoordsModelFile(cdsA, filename);
+    WriteTheseusCdsModelFile(cdsA, filename);
 
     GibbsMeanDiag(cdsA, r2);
 }
 
 
 static void
-GibbsTrans(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          var = cdsA->stats->var;
     double          tvar = sqrt(var / vlen);
-    Coords         *cdsi = NULL;
+    Cds         *cdsi = NULL;
 
 /*     printf("\ntvar: % e", tvar); */
 /*     fflush(NULL); */
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = cdsA->coords[i];
+        cdsi = cdsA->cds[i];
         CenMass(cdsi);
 
 /*         printf("\n  trans[%d]", i+1); */
@@ -876,7 +876,7 @@ GibbsTrans(CoordsArray *cdsA, const gsl_rng *r2)
         cdsi->center[2] += gsl_ran_gaussian(r2, tvar);
 
 /*         printf("\nA trans[%d]: % f % f % f\n", i+1,  */
-/*                cdsA->coords[i]->center[0], cdsA->coords[i]->center[1], cdsA->coords[i]->center[2]); */
+/*                cdsA->cds[i]->center[0], cdsA->cds[i]->center[1], cdsA->cds[i]->center[2]); */
 /*         fflush(NULL); */
 
          ApplyCenterIp(cdsi);
@@ -885,12 +885,12 @@ GibbsTrans(CoordsArray *cdsA, const gsl_rng *r2)
 
 
 static void
-GibbsTransDiag(CoordsArray *cdsA, const gsl_rng *r2)
+GibbsTransDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          tvar, invtr;
-    Coords         *cdsi = NULL;
+    Cds         *cdsi = NULL;
 
     invtr = 0.0;
     for (i = 0; i < vlen; ++i)
@@ -905,7 +905,7 @@ GibbsTransDiag(CoordsArray *cdsA, const gsl_rng *r2)
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = cdsA->coords[i];
+        cdsi = cdsA->cds[i];
         CenMassWtIp(cdsi, cdsA->w);
 
 /*         printf("\n  trans[%d]", i+1); */
@@ -923,13 +923,13 @@ GibbsTransDiag(CoordsArray *cdsA, const gsl_rng *r2)
 /*         fflush(NULL); */
 
         ApplyCenterIp(cdsi);
-        //NegTransCoordsIp(cdsi, cdsi->center);
+        //NegTransCdsIp(cdsi, cdsi->center);
     }
 }
 
 
 static void
-CoordsInnerProduct(double *A, Coords *cds1, Coords *cds2, const int vlen, const double *weight)
+CdsInnerProduct(double *A, Cds *cds1, Cds *cds2, const int vlen, const double *weight)
 {
     double          x1, x2, y1, y2, z1, z2;
     int             i;
@@ -1048,13 +1048,13 @@ MardiaRot3(double *R, const double *t)
    Esp. pp 241-242.
 */
 static void
-GibbsMetRot(CoordsArray *cdsA, double **theta, const gsl_rng *r2)
+GibbsMetRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
 {
     int             i, j, k;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          var = cdsA->stats->var;
     double        **F = cdsA->tmpmat3a;
-    Coords         *ave = cdsA->avecoords;
+    Cds         *ave = cdsA->avecds;
     double          a12, b12, a13, b13, a23, b23;
     double          kap12, kap23, m, t12, t13, t23, width;
     double        **rotmat = NULL;
@@ -1067,9 +1067,9 @@ GibbsMetRot(CoordsArray *cdsA, double **theta, const gsl_rng *r2)
                                /* I do the same for the translations. */
                                /* We can't do this if the chains are run out of place */
         if (cdsA->algo->varweight > 0)
-            CoordsInnerProduct(&F[0][0], ave, cdsA->coords[i], vlen, cdsA->w);
+            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, cdsA->w);
         else
-            CoordsInnerProduct(&F[0][0], ave, cdsA->coords[i], vlen, NULL);
+            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, NULL);
 /*         printf("\n\n****************\nstructure: %d", i+1); */
 /*         printf("\nF:"); */
 /*         Mat3Print(F); */
@@ -1118,7 +1118,7 @@ GibbsMetRot(CoordsArray *cdsA, double **theta, const gsl_rng *r2)
 
 /*         printf("\ntheta: % f % f % f\n", theta[i][0], theta[i][1], theta[i][2]); */
 
-        rotmat = cdsA->coords[i]->matrix;
+        rotmat = cdsA->cds[i]->matrix;
         MardiaRot3(&rotmat[0][0], theta[i]);
 
 /*         printf("\nrotmat:"); */
@@ -1133,13 +1133,13 @@ GibbsMetRot(CoordsArray *cdsA, double **theta, const gsl_rng *r2)
 
         Mat3TransposeIp(rotmat);
 
-        RotateCoordsIp(cdsA->coords[i], (const double **) rotmat);
+        RotateCdsIp(cdsA->cds[i], (const double **) rotmat);
     }
 }
 
 
 static void
-WriteSample(FILE *paramfile, CoordsArray *cdsA, double **theta, const int iter)
+WriteSample(FILE *paramfile, CdsArray *cdsA, double **theta, const int iter)
 {
     int             j, k;
     double         *quat = malloc(4 * sizeof(double));
@@ -1163,11 +1163,11 @@ WriteSample(FILE *paramfile, CoordsArray *cdsA, double **theta, const int iter)
 
     for (j = 0; j < vlen; ++j)
         fprintf(paramfile, "%-12s %6d % 14.9f % 14.9f % 14.9f\n", "MEAN", 
-                j+1, cdsA->avecoords->x[j], cdsA->avecoords->y[j], cdsA->avecoords->z[j]);
+                j+1, cdsA->avecds->x[j], cdsA->avecds->y[j], cdsA->avecds->z[j]);
 
     for (k = 0; k < cnum; ++k)
         fprintf(paramfile, "%-12s %6d % 18.9e % 18.9e % 18.9e\n", "TRANS", 
-                k+1, cdsA->coords[k]->center[0], cdsA->coords[k]->center[1], cdsA->coords[k]->center[2]);
+                k+1, cdsA->cds[k]->center[0], cdsA->cds[k]->center[1], cdsA->cds[k]->center[2]);
 
     for (k = 0; k < cnum; ++k)
     {
@@ -1178,9 +1178,9 @@ WriteSample(FILE *paramfile, CoordsArray *cdsA, double **theta, const int iter)
             fprintf(paramfile,
                     //"% 12.3e % 12.3e % 12.3e",
                     "% 12.9f % 12.9f % 12.9f    ",
-                    cdsA->coords[k]->matrix[j][0],
-                    cdsA->coords[k]->matrix[j][1],
-                    cdsA->coords[k]->matrix[j][2]);
+                    cdsA->cds[k]->matrix[j][0],
+                    cdsA->cds[k]->matrix[j][1],
+                    cdsA->cds[k]->matrix[j][2]);
         }
 
         fputc('\n', paramfile);
@@ -1192,14 +1192,14 @@ WriteSample(FILE *paramfile, CoordsArray *cdsA, double **theta, const int iter)
 
     for (k = 0; k < cnum; ++k)
     {
-        RotMatToQuaternion((const double **) cdsA->coords[k]->matrix, quat);
+        RotMatToQuaternion((const double **) cdsA->cds[k]->matrix, quat);
         fprintf(paramfile, "%-12s %6d % 18.9e % 18.9e % 18.9e % 18.9e\n", "QUAT", 
                 k+1, quat[0], quat[1], quat[2], quat[3]);
     }
 
     if (cdsA->algo->scale > 0)
         for (j = 0; j < cnum; ++j)
-            fprintf(paramfile, "%-12s %6d %18.9e\n", "SCALE", j+1, cdsA->coords[j]->scale);
+            fprintf(paramfile, "%-12s %6d %18.9e\n", "SCALE", j+1, cdsA->cds[j]->scale);
 
     fprintf(paramfile, "%-12s %12d\n", "END SAMPLE", iter);
     free(quat);
@@ -1207,7 +1207,7 @@ WriteSample(FILE *paramfile, CoordsArray *cdsA, double **theta, const int iter)
 
 
 void
-RandInitGibbs(CoordsArray *cdsA, const gsl_rng *r2)
+RandInitGibbs(CdsArray *cdsA, const gsl_rng *r2)
 {
     const int      cnum = cdsA->cnum, vlen = cdsA->vlen;
     int            slxn, i;
@@ -1217,24 +1217,24 @@ RandInitGibbs(CoordsArray *cdsA, const gsl_rng *r2)
     cdsA->stats->phi = 0.0; 
     for (i = 0; i < vlen; ++i) 
         cdsA->w[i] = cdsA->var[i] = 1.0; 
-    RandRotCoordsArray(cdsA, r2); 
-    RandTransCoordsArray(cdsA, 1000.0, r2); 
+    RandRotCdsArray(cdsA, r2); 
+    RandTransCdsArray(cdsA, 1000.0, r2); 
 
-    CoordsCopyAll(cdsA->avecoords, cdsA->coords[slxn]); 
+    CdsCopyAll(cdsA->avecds, cdsA->cds[slxn]); 
 }
 
 
 static double
-CalcFrobTerm(CoordsArray *cdsA)
+CalcFrobTerm(CdsArray *cdsA)
 {
     int             k, m;;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const double   *var = (const double *) cdsA->var;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    const Coords   *coordsm = NULL;
-    const double   *avex = (const double *) cdsA->avecoords->x,
-                   *avey = (const double *) cdsA->avecoords->y,
-                   *avez = (const double *) cdsA->avecoords->z;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    const Cds   *cdsm = NULL;
+    const double   *avex = (const double *) cdsA->avecds->x,
+                   *avey = (const double *) cdsA->avecds->y,
+                   *avez = (const double *) cdsA->avecds->z;
     double          fterm, tmpx, tmpy, tmpz;
 
     fterm = 0.0;
@@ -1242,11 +1242,11 @@ CalcFrobTerm(CoordsArray *cdsA)
     {
         for (m = 0; m < cnum; ++m)
         {
-            coordsm = (Coords *) coords[m];
+            cdsm = (Cds *) cds[m];
 
-            tmpx = coordsm->x[k] - avex[k];
-            tmpy = coordsm->y[k] - avey[k];
-            tmpz = coordsm->z[k] - avez[k];
+            tmpx = cdsm->x[k] - avex[k];
+            tmpy = cdsm->y[k] - avey[k];
+            tmpz = cdsm->z[k] - avez[k];
 
             fterm += (tmpx*tmpx + tmpy*tmpy + tmpz*tmpz) / var[k];
         }
@@ -1257,15 +1257,15 @@ CalcFrobTerm(CoordsArray *cdsA)
 
 
 static double
-CalcFrobTermIso(CoordsArray *cdsA)
+CalcFrobTermIso(CdsArray *cdsA)
 {
     int             k, m;;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    const Coords  **coords = (const Coords **) cdsA->coords;
-    const Coords   *coordsm = NULL;
-    const double   *avex = (const double *) cdsA->avecoords->x,
-                   *avey = (const double *) cdsA->avecoords->y,
-                   *avez = (const double *) cdsA->avecoords->z;
+    const Cds  **cds = (const Cds **) cdsA->cds;
+    const Cds   *cdsm = NULL;
+    const double   *avex = (const double *) cdsA->avecds->x,
+                   *avey = (const double *) cdsA->avecds->y,
+                   *avez = (const double *) cdsA->avecds->z;
     double          fterm, tmpx, tmpy, tmpz;
 
     fterm = 0.0;
@@ -1273,11 +1273,11 @@ CalcFrobTermIso(CoordsArray *cdsA)
     {
         for (m = 0; m < cnum; ++m)
         {
-            coordsm = (Coords *) coords[m];
+            cdsm = (Cds *) cds[m];
 
-            tmpx = coordsm->x[k] - avex[k];
-            tmpy = coordsm->y[k] - avey[k];
-            tmpz = coordsm->z[k] - avez[k];
+            tmpx = cdsm->x[k] - avex[k];
+            tmpy = cdsm->y[k] - avey[k];
+            tmpz = cdsm->z[k] - avez[k];
 
             fterm += (tmpx*tmpx + tmpy*tmpy + tmpz*tmpz);
         }
@@ -1288,7 +1288,7 @@ CalcFrobTermIso(CoordsArray *cdsA)
 
 
 static double
-CalcHierarchPrLogL(CoordsArray *cdsA)
+CalcHierarchPrLogL(CdsArray *cdsA)
 {
     const double   *var = (const double *) cdsA->var;
     const int       vlen = cdsA->vlen;
@@ -1298,20 +1298,20 @@ CalcHierarchPrLogL(CoordsArray *cdsA)
 
 
 static double
-CalcLogScaleJacob(CoordsArray *cdsA)
+CalcLogScaleJacob(CdsArray *cdsA)
 {
     double         scales;
     int            i;
 
     scales = 0.0;
     for (i = 0; i < cdsA->cnum; ++i)
-        scales += log(cdsA->coords[i]->scale);
+        scales += log(cdsA->cds[i]->scale);
 
     return(3.0 * cdsA->vlen * scales);
 }
 
 static double
-CalcLogLGibbs(CoordsArray *cdsA)
+CalcLogLGibbs(CdsArray *cdsA)
 {
     const int       vlen = cdsA->vlen;
     const double    cnum = cdsA->cnum;
@@ -1374,7 +1374,7 @@ f(double x, void *params)
 
 
 void
-GibbsMet(CoordsArray *cdsA)
+GibbsMet(CdsArray *cdsA)
 {
     int                     i;
     const int               cnum = cdsA->cnum, vlen = cdsA->vlen;
@@ -1386,7 +1386,7 @@ GibbsMet(CoordsArray *cdsA)
     gsl_rng                *r2 = NULL;
     double                  invtr, mlik, hmlik, blik, amlik, diff, ediff, liksi;
     int                     badsamp, nsamp, burnin = 100;
-    Coords                 *avecds = cdsA->avecoords;
+    Cds                 *avecds = cdsA->avecds;
     FILE                   *paramfile = NULL;
 
     double *liks = malloc(burn * sizeof(double));
@@ -1438,12 +1438,12 @@ GibbsMet(CoordsArray *cdsA)
     //////////////////////////////////////////
     //RandInitGibbs(cdsA, r2);
 
-    CalcCdsPrincAxes(avecds, avecds->matrix, cdsA->w);
+    CalcCdsPrincAxesGibbs(avecds, avecds->matrix, cdsA->w);
     Mat3TransposeIp(avecds->matrix);
-    RotateCoordsIp(avecds, (const double **) avecds->matrix);
+    RotateCdsIp(avecds, (const double **) avecds->matrix);
 
     for (i = 0; i < cnum; ++i)
-        RotateCoordsIp(cdsA->coords[i], (const double **) avecds->matrix);
+        RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
 
 //     if (cdsA->algo->varweight > 0)
 //          GibbsMeanDiagWrite(cdsA, r2, 0);
@@ -1454,9 +1454,9 @@ GibbsMet(CoordsArray *cdsA)
 
     for (i = 0; i < cnum; ++i)
     {
-        //ScaleCoords(cdsA->coords[i], i+1.0);
-        //cdsA->coords[i]->scale = i+1.0;
-        cdsA->coords[i]->scale = 15;
+        //ScaleCds(cdsA->cds[i], i+1.0);
+        //cdsA->cds[i]->scale = i+1.0;
+        cdsA->cds[i]->scale = 15;
     }
 
     VarCds(cdsA);
@@ -1501,7 +1501,7 @@ GibbsMet(CoordsArray *cdsA)
             WriteSample(paramfile, cdsA, theta, i);
 
 /*             sprintf(tmpname, "%s_%s_%05d.pdb", cdsA->algo->rootname, "gibbs_ave", i); */
-/*             WriteAveCoords(cdsA, tmpname); */
+/*             WriteAveCds(cdsA, tmpname); */
         }
     }
 
