@@ -27,18 +27,18 @@
 #define MULTIPOSE2MSA_SEEN
 
 void
-Align2segID(PDBCoordsArray *pdbA);
+Align2segID(PDBCdsArray *pdbA);
 
 void
-Align2Vars(PDBCoordsArray *pdbA, CoordsArray *cds);
+Align2Vars(PDBCdsArray *pdbA, CdsArray *cds);
 
 void
-Align2MSA(PDBCoordsArray *pdbA, CoordsArray *baseA, char *msafile_name, char *mapfile_name);
+Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_name);
 
 double
-CalcRotationsOcc(CoordsArray *cdsA);
+CalcRotationsOcc(CdsArray *cdsA);
 
 void
-pdb2fst(PDBCoordsArray *pdbA);
+pdb2fst(PDBCdsArray *pdbA);
 
 #endif
