@@ -28,7 +28,6 @@
 #include <string.h>
 #include <math.h>
 #include <float.h>
-
 #include "CovMat.h"
 #include "DLTutils.h"
 #include "DLTmath.h"
@@ -36,11 +35,10 @@
 #include "PCAstats.h"
 #include "pdbIO.h"
 #include "pdbMalloc.h"
-#include "Coords.h"
-#include "PDBCoords.h"
+#include "Cds.h"
+#include "PDBCds.h"
 #include "pdbStats.h"
 #include "pdbUtils.h"
-#include "lapack_dlt.h"
 
 
 #if defined(__APPLE__)
@@ -56,14 +54,14 @@
 
 
 void
-CalcPCA(CoordsArray *cdsA)
+CalcPCA(CdsArray *cdsA)
 {
     int            i, j;
     int            vlen = (int) cdsA->vlen;
     int            upper, lower, pcanum;
     double       **CovMat = cdsA->CovMat;
     double         sum, runsum;
-    PDBCoords     *pdbave;
+    PDBCds     *pdbave;
     char           pcafile_name[256];
     FILE          *pcavecs_fp, *pcastats_fp;
     double         biggest, bstick;
@@ -76,7 +74,7 @@ CalcPCA(CoordsArray *cdsA)
         start_time = seconds();
     #endif
 
-    pdbave = cdsA->pdbA->avecoords;
+    pdbave = cdsA->pdbA->avecds;
     pcanum = cdsA->algo->pca;
 
     if (pcanum > cdsA->vlen)
@@ -105,15 +103,22 @@ CalcPCA(CoordsArray *cdsA)
 
     lower = vlen - pcanum + 1; /* careful -- inclusive indices */
     upper = vlen - 0;
-    cdsA->pcamat = MatAlloc(pcanum, vlen);
+    //cdsA->pcamat = MatAlloc(pcanum, vlen);
+    cdsA->pcamat = MatAlloc(vlen, vlen);
     cdsA->pcavals = malloc(vlen * sizeof(double));
 
+    EigenGSLDest(CovMat, vlen, cdsA->pcavals, cdsA->pcamat, 1);
+    MatTransIp(cdsA->pcamat, vlen);
+    //MatPrint(cdsA->pcamat, vlen);
+
     /* LAPACK DSYEVR() computes selected eigenvalues, and optionally, eigenvectors of a
        real symmetric matrix.  Find all eigenvalues (w[]) and eigenvectors (mat[][]).
        The pcanum eigenvalues are in the first pcanum elements of the w[] vector,
        ordered smallest to biggest.  Weird and horrible, but true (and in fact
        makes sense if you think about it). */
-    dsyevr_dest(CovMat, vlen, lower, upper, cdsA->pcavals, cdsA->pcamat, 1e-8);
+    //dsyevr_dest(CovMat, vlen, lower, upper, cdsA->pcavals, cdsA->pcamat, 1e-8);
+
+    //MatPrint(cdsA->pcamat, vlen);
 
     #if defined(__APPLE__)
         end_time = seconds();
@@ -135,10 +140,11 @@ CalcPCA(CoordsArray *cdsA)
 
     runsum = 0.0;
     fprintf(pcastats_fp, "eigenv   bstick     raw    raw_%%  cumul_%% \n");
-    for (i = pcanum - 1; i >= 0; --i)
+
+    for (i = 0; i < pcanum; ++i)
     {
         bstick = 0.0;
-        for (j = vlen - i; j <= vlen; ++j)
+        for (j = i+1; j <= vlen; ++j)
             bstick += (1.0 / (double) j);
 
         if (bstick < cdsA->pcavals[i] && cdsA->pcavals[i] > 1.0)
@@ -148,42 +154,43 @@ CalcPCA(CoordsArray *cdsA)
 
         runsum += cdsA->pcavals[i];
         fprintf(pcastats_fp, "%-6i %8.3f %8.3f %8.3f %8.3f %c\n",
-                pcanum - i, bstick, cdsA->pcavals[i],
+                i+1, bstick, cdsA->pcavals[i],
                 cdsA->pcavals[i] * 100.0 / sum, runsum * 100.0 / sum, aster);
     }
     fputc('\n', pcastats_fp);
 
     fprintf(pcavecs_fp, "atom ");
-    for (j = 1; j <= pcanum; ++j)
-        fprintf(pcavecs_fp, "     %3d ", j);
+    for (j = 0; j < pcanum; ++j)
+        fprintf(pcavecs_fp, "     %3d ", j+1);
     fputc('\n', pcavecs_fp);
 
     for (i = 0; i < vlen; ++i)
     {
         fprintf(pcavecs_fp, "%-4d ", i+1);
 
-        for (j = 1; j <= pcanum; ++j)
-            fprintf(pcavecs_fp, "%8.3f ", sqrt(cdsA->pcavals[pcanum - j]) * cdsA->pcamat[pcanum - j][i]);
+        for (j = 0; j < pcanum; ++j)
+            fprintf(pcavecs_fp, "%8.3f ", sqrt(cdsA->pcavals[j]) * cdsA->pcamat[j][i]);
 
         fputc('\n', pcavecs_fp);
     }
 
-    CopyCoords2PDB(pdbave, cdsA->avecoords);
+    CopyCds2PDB(pdbave, cdsA->avecds);
 
     for (i = 0; i < pcanum; ++i)
     {
+        //printf("\neigenval %d: %g\n", i, cdsA->pcavals[i]);
         /* find largest absolute value in the eigenvector PCA */
         biggest = -DBL_MAX;
         for (j = 0; j < vlen; ++j)
-            if (biggest < fabs(cdsA->pcamat[pcanum - 1 - i][j]))
-                biggest = fabs(cdsA->pcamat[pcanum - 1 - i][j]);
+            if (biggest < fabs(cdsA->pcamat[i][j]))
+                biggest = fabs(cdsA->pcamat[i][j]);
 
         /* rescale (for rasmol really) so that the largest eigenvalue component
            is = 99.99, i.e. the largest value allowable in the b-value column 
            of a PDB file */
         /* biggest = 1.0; */
         for (j = 0; j < vlen; ++j)
-            cdsA->pdbA->avecoords->tempFactor[j] = cdsA->pcamat[pcanum - 1 - i][j] * (99.99 / biggest);
+            cdsA->pdbA->avecds->tempFactor[j] = cdsA->pcamat[i][j] * (99.99 / biggest);
 
         sprintf(pcafile_name, "%s_pc%d_ave.pdb", cdsA->algo->rootname, i+1);
 
@@ -192,16 +199,17 @@ CalcPCA(CoordsArray *cdsA)
         //strncat(pcafile_name, itoa(i+1, &numstring[0], 10), 5);
         //strncat(pcafile_name, "_ave.pdb", 8);
 
-        WriteAvePDBCoordsFile(cdsA->pdbA, pcafile_name);
+        WriteAvePDBCdsFile(cdsA->pdbA, pcafile_name);
     }
 
-    for (i = 0; i < vlen; ++i)
-        for (j = 0; j < pcanum; ++j)
-            cdsA->pcamat[j][i] *= sqrt(cdsA->pcavals[j]);
-
     if (pcanum == vlen)
     {
         char *pcvecs_mat_name = mystrcat(cdsA->algo->rootname, "_pcvecs.mat");
+
+		for (i = 0; i < vlen; ++i)
+			for (j = 0; j < pcanum; ++j)
+				cdsA->pcamat[j][i] *= sqrt(cdsA->pcavals[j]);
+
         PrintCovMatGnuPlot((const double **) cdsA->pcamat, vlen, pcvecs_mat_name);
         free(pcvecs_mat_name);
     }
@@ -224,15 +232,15 @@ CalcPCA(CoordsArray *cdsA)
 
 
 void
-Calc3NPCA(CoordsArray *cdsA)
+Calc3NPCA(CdsArray *cdsA)
 {
     int                      i, j;
-    int                 vlen = (int) 3 * cdsA->vlen;
+    int                      vlen = (int) 3 * cdsA->vlen;
     double                 **mat = NULL;
-    int                 upper, lower, pcanum;
+    int                      upper, lower, pcanum;
     double                 **evecs = NULL, *evals = NULL;
     double                   sum, runsum;
-    PDBCoords               *pdbave = NULL;
+    PDBCds               *pdbave = NULL;
     char                     pcafile_name[256];
     FILE                    *pcavecs_fp = NULL, *pcastats_fp = NULL;
     double                   biggest, bstick;
@@ -243,7 +251,7 @@ Calc3NPCA(CoordsArray *cdsA)
         start_time = seconds();
     #endif
 
-    pdbave = cdsA->pdbA->avecoords;
+    pdbave = cdsA->pdbA->avecds;
     mat = MatAlloc(vlen, vlen);
 
     if (cdsA->algo->pca > cdsA->cnum - 1)
@@ -252,7 +260,7 @@ Calc3NPCA(CoordsArray *cdsA)
         pcanum = cdsA->algo->pca;
 
     /* copy over the covariance matrix */
-    memcpy(&mat[0][0], &cdsA->FullCovMat[0][0], vlen * vlen * sizeof(double));
+    memcpy(mat[0], cdsA->FullCovMat[0], vlen * vlen * sizeof(double));
     /* MatPrint(cdsA->FullCovMat, vlen); */
     /* fflush(NULL); */
 
@@ -267,7 +275,7 @@ Calc3NPCA(CoordsArray *cdsA)
 
     lower = vlen - pcanum + 1; /* careful -- inclusive indices */
     upper = vlen - 0;
-    evecs = MatAlloc(pcanum, vlen);
+    evecs = MatAlloc(vlen, vlen);
     evals = malloc(vlen * sizeof(double));
 
     /* LAPACK DSYEVR() computes selected eigenvalues, and optionally, eigenvectors of a
@@ -275,7 +283,11 @@ Calc3NPCA(CoordsArray *cdsA)
        The pcanum eigenvalues are in the first pcanum elements of the w[] vector,
        ordered smallest to biggest.  Weird and horrible, but true (and in fact
        makes sense if you think about it). */
-    dsyevr_opt_dest(mat, vlen, lower, upper, evals, evecs, 1e-8);
+    //dsyevr_opt_dest(mat, vlen, lower, upper, evals, evecs, 1e-8);
+
+    EigenGSLDest(mat, vlen, evals, evecs, 1);
+    MatTransIp(cdsA->pcamat, vlen);
+
     PrintCovMatGnuPlot((const double **) evecs, vlen, "evecs.mat");
 
     #if defined(__APPLE__)
@@ -295,10 +307,11 @@ Calc3NPCA(CoordsArray *cdsA)
 
     runsum = 0.0;
     fprintf(pcastats_fp, "eigenv   bstick     raw    raw_%%  cumul_%% \n");
-    for (i = pcanum - 1; i >= 0; --i)
+
+    for (i = 0; i < pcanum; ++i)
     {
         bstick = 0.0;
-        for (j = vlen - i; j <= vlen; ++j)
+        for (j = i+1; j <= vlen; ++j)
             bstick += (1.0 / (double) j);
 
         if (bstick < evals[i] && evals[i] > 1.0)
@@ -306,42 +319,43 @@ Calc3NPCA(CoordsArray *cdsA)
         else
             aster = ' ';
 
-        runsum += evals[i];
+        runsum += cdsA->pcavals[i];
         fprintf(pcastats_fp, "%-6i %8.3f %8.3f %8.3f %8.3f %c\n",
-                pcanum - i, bstick, evals[i], evals[i] * 100.0 / sum, runsum * 100.0 / sum, aster);
+                i+1, bstick, evals[i],
+                evals[i] * 100.0 / sum, runsum * 100.0 / sum, aster);
     }
     fputc('\n', pcastats_fp);
 
     fprintf(pcavecs_fp, "atom ");
-    for (j = 1; j <= pcanum; ++j)
-        fprintf(pcavecs_fp, "     %3d ", j);
+    for (j = 0; j < pcanum; ++j)
+        fprintf(pcavecs_fp, "     %3d ", j+1);
     fputc('\n', pcavecs_fp);
 
     for (i = 0; i < vlen; ++i)
     {
         fprintf(pcavecs_fp, "%-4d ", i+1);
 
-        for (j = 1; j <= pcanum; ++j)
-            fprintf(pcavecs_fp, "%8.3f ", sqrt(evals[pcanum - j]) * evecs[pcanum - j][i]);
+        for (j = 0; j < pcanum; ++j)
+            fprintf(pcavecs_fp, "%8.3f ", sqrt(evals[j]) * evecs[j][i]);
 
         fputc('\n', pcavecs_fp);
     }
 
-    CopyCoords2PDB(pdbave, cdsA->avecoords);
+    CopyCds2PDB(pdbave, cdsA->avecds);
 
     for (i = 0; i < pcanum; ++i)
     {
         /* find largest absolute value in the eigenvector PCA */
         biggest = -DBL_MAX;
         for (j = 0; j < vlen; ++j)
-            if (biggest < fabs(evecs[pcanum - 1 - i][j]))
-                biggest = fabs(evecs[pcanum - 1 - i][j]);
+            if (biggest < fabs(evecs[i][j]))
+                biggest = fabs(evecs[i][j]);
 
         /* rescale (for rasmol really) so that the largest eigenvalue component
            is = 99.99, i.e. the largest value allowable in the b-value column 
            of a PDB file */
         for (j = 0; j < vlen; ++j)
-            cdsA->pdbA->avecoords->tempFactor[j] = evecs[pcanum - 1 - i][j] * (99.99 / biggest);
+            cdsA->pdbA->avecds->tempFactor[j] = evecs[i][j] * (99.99 / biggest);
 
         sprintf(pcafile_name, "%s_pc%d", cdsA->algo->rootname, i+1);
 
@@ -349,7 +363,7 @@ Calc3NPCA(CoordsArray *cdsA)
         //pcafile_name[11] = '\0';
         //strncat(pcafile_name, itoa(i+1, &numstring[0], 10), 5);
 
-        WriteAvePDBCoordsFile(cdsA->pdbA, pcafile_name);
+        WriteAvePDBCdsFile(cdsA->pdbA, pcafile_name);
     }
 
     cdsA->pcamat = evecs; /* DLT debug -- this should be copied or dealt with better */
@@ -363,16 +377,13 @@ Calc3NPCA(CoordsArray *cdsA)
 
 
 void
-CalcStructPCA(CoordsArray *cdsA)
+CalcStructPCA(CdsArray *cdsA)
 {
     int                      i, j;
-    int                 cnum = (int) cdsA->cnum;
+    int                      cnum = (int) cdsA->cnum;
     double                 **mat = MatAlloc(cnum, cnum);
-    int                 info = 0;
-    char                     jobz_v = 'V';
-    char                     uplo_u = 'U';
-    int                 lwork, negone = -1;
-    double                  *work = NULL, *w = NULL;
+    double                 **evecs = MatAlloc(cnum, cnum);
+    double                  *w = NULL;
     double                   sum, runsum;
     FILE                    *pcavecs_fp = NULL, *pcastats_fp = NULL;
 
@@ -382,7 +393,7 @@ CalcStructPCA(CoordsArray *cdsA)
     CalcStructCovMat(cdsA);
 
     /* copy over the covariance matrix */
-    memcpy(&mat[0][0], &cdsA->SCovMat[0][0], cnum * cnum * sizeof(double));
+    memcpy(mat[0], cdsA->SCovMat[0], cnum * cnum * sizeof(double));
 
 /*     MatPrint(cdsA->SCovMat, cnum); */
 /*     fflush(NULL); */
@@ -397,35 +408,9 @@ CalcStructPCA(CoordsArray *cdsA)
        sum += mat[i][i];
 
     w = (double *) malloc(cnum * sizeof(double));
-    work = (double *) malloc(sizeof(double));
-
-    /* first DSYEVR() call lwork and liwork = -1 which
-       makes dsyevr calculate optimum workspace given
-       the other params */
-    DSYEV(&jobz_v, &uplo_u, &cnum, &mat[0][0], &cnum, w, work, &negone, &info);
-
-    lwork = work[0];
-    free(work);
-    work = (double *) malloc(lwork * sizeof(double));
-
-    DSYEV(&jobz_v, &uplo_u, &cnum, &mat[0][0], &cnum, w, work, &lwork, &info);
-
-    if (info > 0)
-    {
-        fprintf(stderr, "\n  ERROR117: LAPACK DSYEV() complete eigenvalue/eigenvector solving choked; \n");
-        fprintf(stderr, "            the algorithm failed to converge; %d \n", info);
-        fprintf(stderr, "            off-diagonal elements of an intermediate tridiagonal \n");
-        fprintf(stderr, "            form did not converge to zero \n");
-        PrintTheseusTag();
-        exit(EXIT_FAILURE);
-    }
-    else if (info < 0)
-    {
-
-        fprintf(stderr, "\n  ERROR118: the %d-th argument had an illegal value \n", info);
-        PrintTheseusTag();
-        exit(EXIT_FAILURE);
-    }
+    
+    EigenGSLDest(mat, cnum, w, evecs, 1);
+    MatTransIp(evecs, cnum);
 
     pcavecs_fp = myfopen(mystrcat(cdsA->algo->rootname, "_struct_pcvecs.txt"), "w");
     pcastats_fp = myfopen(mystrcat(cdsA->algo->rootname, "_struct_pcstats.txt"), "w");
@@ -438,25 +423,26 @@ CalcStructPCA(CoordsArray *cdsA)
 
     runsum = 0.0;
     fprintf(pcastats_fp, "eigenv   raw    raw_%%  cumul_%% \n");
+
     for (i = cnum - 1; i >= 0; --i)
     {
         runsum += w[i];
         fprintf(pcastats_fp, "%-6i %8.3f %8.3f %8.3f\n",
-                cnum - i, w[i], w[i] * 100.0 / sum, runsum * 100.0 / sum);
+                i+1, w[i], w[i] * 100.0 / sum, runsum * 100.0 / sum);
     }
     fputc('\n', pcastats_fp);
 
     fprintf(pcavecs_fp, "model ");
-    for (j = 1; j <= cnum; ++j)
-        fprintf(pcavecs_fp, "    %3d ", j);
+    for (j = 0; j < cnum; ++j)
+        fprintf(pcavecs_fp, "    %3d ", j+1);
     fputc('\n', pcavecs_fp);
 
     for (i = 0; i < cnum; ++i)
     {
         fprintf(pcavecs_fp, "%-4d ", i+1);
 
-        for (j = 1; j <= cnum; ++j)
-            fprintf(pcavecs_fp, "%8.3f ", sqrt(w[cnum - j]) * mat[cnum - j][i]);
+        for (j = 0; j < cnum; ++j)
+            fprintf(pcavecs_fp, "%8.3f ", sqrt(w[j]) * mat[j][i]);
 
         fputc('\n', pcavecs_fp);
     }
@@ -466,12 +452,12 @@ CalcStructPCA(CoordsArray *cdsA)
 
     fclose(pcastats_fp);
     fclose(pcavecs_fp);
-    free(work);
+    MatDestroy(&evecs);
 }
 
 
 void
-WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root)
+WritePCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root)
 {
     FILE           *pdbfile = NULL;
     char            pcafile_name[256];
@@ -507,10 +493,10 @@ WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root
             m = 0;
             for (j = 0; j < cvlen; ++j)
             {
-                /* skip inital PDBCoords that may have been selected out */ /* DLT debug fix */
-                while (/* strncmp(cdsA->coords[0]->resName[j], parray->coords[0]->resName[m], 3) != 0 || */
-                       cdsA->coords[0]->chainID[j] != parray->coords[0]->chainID[m] ||
-                       cdsA->coords[0]->resSeq[j] != parray->coords[0]->resSeq[m])
+                /* skip inital PDBCds that may have been selected out */ /* DLT debug fix */
+                while (/* strncmp(cdsA->cds[0]->resName[j], parray->cds[0]->resName[m], 3) != 0 || */
+                       cdsA->cds[0]->chainID[j] != parray->cds[0]->chainID[m] ||
+                       cdsA->cds[0]->resSeq[j] != parray->cds[0]->resSeq[m])
                 {
                     ++m;
 
@@ -519,14 +505,14 @@ WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root
                 }
 
                 /* while they match, set the B-factor according to the given PC */
-                while (/* strncmp(cdsA->coords[0]->resName[j], parray->coords[0]->resName[m], 3) == 0 && */
-                       cdsA->coords[0]->chainID[j] == parray->coords[0]->chainID[m] &&
-                       cdsA->coords[0]->resSeq[j] == parray->coords[0]->resSeq[m])
+                while (/* strncmp(cdsA->cds[0]->resName[j], parray->cds[0]->resName[m], 3) == 0 && */
+                       cdsA->cds[0]->chainID[j] == parray->cds[0]->chainID[m] &&
+                       cdsA->cds[0]->resSeq[j] == parray->cds[0]->resSeq[m])
                 {
                     tempFactor = mat[cdsA->algo->pca - 1 - i][j] * biggest;
                     /* printf("\n%4d %4d % f", j, m, tempFactor); */
                     for (k = 0; k < parray->cnum; ++k)
-                        parray->coords[k]->tempFactor[m] = tempFactor;
+                        parray->cds[k]->tempFactor[m] = tempFactor;
 
                     ++m;
 
@@ -545,7 +531,7 @@ WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root
                 tempFactor = mat[cdsA->algo->pca - 1 - i][j] * biggest;
 
                 for (k = 0; k < parray->cnum; ++k)
-                    parray->coords[k]->tempFactor[j] = tempFactor;
+                    parray->cds[k]->tempFactor[j] = tempFactor;
             }
         }
 
@@ -581,7 +567,7 @@ WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root
         for (j = 0; j < parray->cnum; ++j)
         {
             fprintf(pdbfile, "MODEL %8d\n", j+1);
-            PrintPDBCoords(pdbfile, parray->coords[j]);
+            PrintPDBCds(pdbfile, parray->cds[j]);
             fprintf(pdbfile, "ENDMDL\n");
         }
         fprintf(pdbfile, "END\n");
@@ -594,7 +580,7 @@ WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root
 
 
 void
-WriteModelPCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root)
+WriteModelPCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root)
 {
     FILE           *pdbfile = NULL;
     char            pcafile_name[256];
@@ -627,7 +613,7 @@ WriteModelPCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile
             tempFactor = mat[pcanum - 1 - i][j] * biggest;
 
             for (k = 0; k < pvlen; ++k)
-                parray->coords[j]->tempFactor[k] = tempFactor;
+                parray->cds[j]->tempFactor[k] = tempFactor;
         }
 
         sprintf(pcafile_name, "%s_mod_pca%d.pdb", outfile_root, i+1);
@@ -662,7 +648,7 @@ WriteModelPCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile
         for (j = 0; j < parray->cnum; ++j)
         {
             fprintf(pdbfile, "MODEL %8d\n", j+1);
-            PrintPDBCoords(pdbfile, parray->coords[j]);
+            PrintPDBCds(pdbfile, parray->cds[j]);
             fprintf(pdbfile, "ENDMDL\n");
         }
         fprintf(pdbfile, "END\n");
@@ -678,7 +664,7 @@ WriteModelPCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile
    Used by CNS/XPLOR in my morph script to incrementally add the PC to the
    median PDB model. */
 void
-WritePCAMorphFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root)
+WritePCAMorphFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root)
 {
     FILE           *pdbfile = NULL;
     char            pcafile_name[256];
@@ -687,16 +673,16 @@ WritePCAMorphFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile
     double         *vals = cdsA->pcavals;
     const int       cvlen = 3 * cdsA->vlen;
     const int       pvlen = parray->vlen;
-    PDBCoords      *pcacoords;
+    PDBCds      *pcacds;
     char            covcor_str[16] = "correlation";
 
-    pcacoords = PDBCoordsInit();
-    PDBCoordsAlloc(pcacoords, pvlen);
-    PDBCoordsCopyAll(pcacoords, parray->coords[0]);
+    pcacds = PDBCdsInit();
+    PDBCdsAlloc(pcacds, pvlen);
+    PDBCdsCopyAll(pcacds, parray->cds[0]);
 
-    memset(pcacoords->x, 0, pvlen * sizeof(double));
-    memset(pcacoords->y, 0, pvlen * sizeof(double));
-    memset(pcacoords->z, 0, pvlen * sizeof(double));
+    memset(pcacds->x, 0, pvlen * sizeof(double));
+    memset(pcacds->y, 0, pvlen * sizeof(double));
+    memset(pcacds->z, 0, pvlen * sizeof(double));
 
     if (cdsA->algo->pca > cdsA->cnum - 1)
         pcanum = cdsA->algo->pca = cdsA->cnum - 1;
@@ -727,22 +713,22 @@ CalcFullCovMat(cdsA);
         m = 0;
         for (j = 0; j < cvlen; j += 3)
         {
-            /* skip inital PDBCoords that may have been selected out */
-            while (strncmp(cdsA->coords[0]->resName[j/3], parray->coords[0]->resName[m], 3) != 0 ||
-                   cdsA->coords[0]->chainID[j/3] != parray->coords[0]->chainID[m] ||
-                   cdsA->coords[0]->resSeq[j/3] != parray->coords[0]->resSeq[m])
+            /* skip inital PDBCds that may have been selected out */
+            while (strncmp(cdsA->cds[0]->resName[j/3], parray->cds[0]->resName[m], 3) != 0 ||
+                   cdsA->cds[0]->chainID[j/3] != parray->cds[0]->chainID[m] ||
+                   cdsA->cds[0]->resSeq[j/3] != parray->cds[0]->resSeq[m])
             {
                 ++m;
             }
 
             /* while they match */
-            while (strncmp(cdsA->coords[0]->resName[j/3], parray->coords[0]->resName[m], 3) == 0 &&
-                   cdsA->coords[0]->chainID[j/3] == parray->coords[0]->chainID[m] &&
-                   cdsA->coords[0]->resSeq[j/3] == parray->coords[0]->resSeq[m])
+            while (strncmp(cdsA->cds[0]->resName[j/3], parray->cds[0]->resName[m], 3) == 0 &&
+                   cdsA->cds[0]->chainID[j/3] == parray->cds[0]->chainID[m] &&
+                   cdsA->cds[0]->resSeq[j/3] == parray->cds[0]->resSeq[m])
             {
-                pcacoords->x[m] = vecs[pcanum - 1 - i][j+0];
-                pcacoords->y[m] = vecs[pcanum - 1 - i][j+1];
-                pcacoords->z[m] = vecs[pcanum - 1 - i][j+2];
+                pcacds->x[m] = vecs[pcanum - 1 - i][j+0];
+                pcacds->y[m] = vecs[pcanum - 1 - i][j+1];
+                pcacds->z[m] = vecs[pcanum - 1 - i][j+2];
 
                 ++m;
 
@@ -779,22 +765,22 @@ CalcFullCovMat(cdsA);
         fprintf(pdbfile, "REMARK ===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-=\n");
         fprintf(pdbfile, "REMARK + File made by Douglas Theobald's THESEUS program \n");
         fprintf(pdbfile, "REMARK + Multiple maximum likelihood superpositioning \n");
-        fprintf(pdbfile, "REMARK + Principal component #%d of %s matrix, one SD in coords fields \n", i+1, covcor_str);
+        fprintf(pdbfile, "REMARK + Principal component #%d of %s matrix, one SD in cds fields \n", i+1, covcor_str);
         fprintf(pdbfile, "REMARK + dtheobald@brandeis.edu \n");
         fprintf(pdbfile, "REMARK =-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===\n");
-        PrintPDBCoords(pdbfile, pcacoords);
+        PrintPDBCds(pdbfile, pcacds);
         fprintf(pdbfile, "END\n");
 
         fclose(pdbfile);
     }
 
-    PDBCoordsDestroy(&pcacoords);
+    PDBCdsDestroy(&pcacds);
     PCADestroy(cdsA);
 }
 
 
 void
-WritePCAProjections(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root)
+WritePCAProjections(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root)
 {
     FILE           *pdbfile = NULL;
     char            pcafile_name[256];
@@ -804,12 +790,12 @@ WritePCAProjections(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfi
     double         *vals = cdsA->pcavals;
     const int       cvlen = 3 * cdsA->vlen;
     const int       pvlen = parray->vlen;
-    PDBCoords      *pcacoords;
+    PDBCds      *pcacds;
     //char            numstring[5], tmpstring[5];
 
-    pcacoords = PDBCoordsInit();
-    PDBCoordsAlloc(pcacoords, pvlen);
-    PDBCoordsCopyAll(pcacoords, parray->coords[0]);
+    pcacds = PDBCdsInit();
+    PDBCdsAlloc(pcacds, pvlen);
+    PDBCdsCopyAll(pcacds, parray->cds[0]);
 
     if (cdsA->algo->pca > cdsA->cnum - 1)
         pcanum = cdsA->algo->pca = cdsA->cnum - 1;
@@ -847,24 +833,24 @@ CalcFullCovMat(cdsA);
             m = 0;
             for (j = 0; j < cvlen; j += 3)
             {
-                /* skip inital PDBCoords that may have been selected out */
-                while (strncmp(cdsA->coords[0]->resName[j/3], parray->coords[0]->resName[m], 3) != 0 ||
-                       cdsA->coords[0]->chainID[j/3] != parray->coords[0]->chainID[m] ||
-                       cdsA->coords[0]->resSeq[j/3] != parray->coords[0]->resSeq[m])
+                /* skip inital PDBCds that may have been selected out */
+                while (strncmp(cdsA->cds[0]->resName[j/3], parray->cds[0]->resName[m], 3) != 0 ||
+                       cdsA->cds[0]->chainID[j/3] != parray->cds[0]->chainID[m] ||
+                       cdsA->cds[0]->resSeq[j/3] != parray->cds[0]->resSeq[m])
                 {
                     ++m;
                 }
 
                 /* while they match */
-                while (strncmp(cdsA->coords[0]->resName[j/3], parray->coords[0]->resName[m], 3) == 0 &&
-                       cdsA->coords[0]->chainID[j/3] == parray->coords[0]->chainID[m] &&
-                       cdsA->coords[0]->resSeq[j/3] == parray->coords[0]->resSeq[m])
+                while (strncmp(cdsA->cds[0]->resName[j/3], parray->cds[0]->resName[m], 3) == 0 &&
+                       cdsA->cds[0]->chainID[j/3] == parray->cds[0]->chainID[m] &&
+                       cdsA->cds[0]->resSeq[j/3] == parray->cds[0]->resSeq[m])
                 {
-                    pcacoords->x[m] = parray->coords[cdsA->cnum/2]->x[m] +
+                    pcacds->x[m] = parray->cds[cdsA->cnum/2]->x[m] +
                                       c * vecs[pcanum - 1 - i][j+0];
-                    pcacoords->y[m] = parray->coords[cdsA->cnum/2]->y[m] +
+                    pcacds->y[m] = parray->cds[cdsA->cnum/2]->y[m] +
                                       c * vecs[pcanum - 1 - i][j+1];
-                    pcacoords->z[m] = parray->coords[cdsA->cnum/2]->z[m] +
+                    pcacds->z[m] = parray->cds[cdsA->cnum/2]->z[m] +
                                       c * vecs[pcanum - 1 - i][j+2];
 
                     ++m;
@@ -903,13 +889,13 @@ CalcFullCovMat(cdsA);
             fprintf(pdbfile, "REMARK + Principal component %d of correlation matrix in B-factor column \n", i+1);
             fprintf(pdbfile, "REMARK + dtheobald@brandeis.edu \n");
             fprintf(pdbfile, "REMARK =-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===\n");
-            PrintPDBCoords(pdbfile, pcacoords);
+            PrintPDBCds(pdbfile, pcacds);
             fprintf(pdbfile, "END\n");
 
             fclose(pdbfile);
         }
     }
 
-    PDBCoordsDestroy(&pcacoords);
+    PDBCdsDestroy(&pcacds);
     PCADestroy(cdsA);
 }
