@@ -1303,16 +1303,15 @@ double
 InvSymEigenOp(double **invmat, const double **mat, int n,
               double *evals, double **evecs, const double tol)
 {
-    int                 info = 0;
-    char                     jobz_v = 'V', uplo_u = 'U';
-    int                 lwork = n * n;
-    double                  *work = &invmat[0][0];
     double                   cond;
     int                      i, j, k;
+    double                 **tmpmat = MatAlloc(n, n);
 
-    memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double));
+    memcpy(tmpmat[0], mat[0], n * n * sizeof(double));
 
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
+    //DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
+
+    EigenGSLDest(tmpmat, n, evals, evecs, 0);
 
     cond = evals[n-1] / evals[0];
 
@@ -1324,17 +1323,19 @@ InvSymEigenOp(double **invmat, const double **mat, int n,
             evals[i] = 0.0;
     }
 
-    memset(&invmat[0][0], 0, n * n * sizeof(double));
+    memset(invmat[0], 0, n * n * sizeof(double));
 
     for (i = 0; i < n; ++i)
         for (j = 0; j <= i; ++j)
             for (k = 0; k < n; ++k)
-                invmat[i][j] += (evecs[k][i] * evals[k] * evecs[k][j]);
+                invmat[i][j] += (evecs[i][k] * evals[k] * evecs[j][k]);
 
     for (i = 0; i < n; ++i)
         for (j = i + 1; j < n; ++j)
             invmat[i][j] = invmat[j][i];
 
+    MatDestroy(&tmpmat);
+
     return(cond);
 }
 
@@ -1348,148 +1349,54 @@ InvSymEigenOp(double **invmat, const double **mat, int n,
 void
 eigensym(const double **mat, double *evals, double **evecs, int n)
 {
-    int                 info = 0;
-    int                 negone = -1;
-    char                     jobz_v = 'V', uplo_u = 'U';
-    int                 lwork;
-    double                  *work = malloc(sizeof(double));
-    double                   tmp;
-    int                      i, j;
-
-    memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double));
-
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &negone, &info);
-    lwork = work[0];
-    free(work);
-    work = malloc(lwork * sizeof(double));
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
-
-    for (i = 0; i < n; ++i)
-    {
-        for (j = 0; j < i; ++j)
-        {
-            tmp = evecs[i][j];
-            evecs[i][j] = evecs[j][i];
-            evecs[j][i] = tmp;
-        }
-    }
-
-    free(work);
+    EigenGSL((double **) mat, n, evals, evecs, 0);
 }
 
 
 /* Entire decomposition, evals and evecs */
 /* eigensym evals are small to large */
 /* exactly the same as eigensym above, but work space is passed */
-void
-eigensym2(const double **mat, double *evals, double **evecs, int n, double *work)
-{
-    int                 info = 0;
-    char                     jobz_v = 'V', uplo_u = 'U';
-    int                 lwork = n * n;
-    double                   tmp;
-    int                      i, j;
-
-    memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double));
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
-
-    for (i = 0; i < n; ++i)
-    {
-        for (j = 0; j < i; ++j)
-        {
-            tmp = evecs[i][j];
-            evecs[i][j] = evecs[j][i];
-            evecs[j][i] = tmp;
-        }
-    }
-}
+/* void */
+/* eigensym2(const double **mat, double *evals, double **evecs, int n, double *work) */
+/* { */
+/*     int                 info = 0; */
+/*     char                     jobz_v = 'V', uplo_u = 'U'; */
+/*     int                 lwork = n * n; */
+/*     double                   tmp; */
+/*     int                      i, j; */
+/*  */
+/*     memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double)); */
+/*     DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info); */
+/*  */
+/*     for (i = 0; i < n; ++i) */
+/*     { */
+/*         for (j = 0; j < i; ++j) */
+/*         { */
+/*             tmp = evecs[i][j]; */
+/*             evecs[i][j] = evecs[j][i]; */
+/*             evecs[j][i] = tmp; */
+/*         } */
+/*     } */
+/* } */
 
 
 void
 eigenvalsym(const double **mat, double *evals, double **evecs, int n)
 {
-    int                 info = 0;
-    int                 negone = -1;
-    char                     jobz_v = 'N', uplo_u = 'U';
-    int                 lwork;
-    double                  *work = malloc(sizeof(double));
-
-    memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double));
-
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &negone, &info);
-    lwork = work[0];
-    free(work);
-    work = malloc(lwork * sizeof(double));
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
-
-    free(work);
+    EigenvalsGSL((double **) mat, n, evals);
 }
 
 
-void
-eigenvalsym2(const double **mat, double *evals, double **evecs, int n, double *work)
-{
-    int                 info = 0;
-    char                     jobz_v = 'N', uplo_u = 'U';
-    int                 lwork = n * n;
-
-    memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double));
-    DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info);
-}
-
-
-/* This one has been quadruple-checked for correctness against
-   Mathematica, for getting the row vs col thing right.
-   NB: LAPACK dgeev does not rank the eigenvalues, which may
-   be complex.
-   With LAPACK, which is Fortran-style, we must transpose the
-   arrays we pass and transpose the arrays returned. In this case,
-   instead of transposing the array we pass, we can accomplish the
-   same end by calculating the left eigenvectors and transposing
-   them to give the right eigenvectors. */
-void
-eigengen(const double **mat, double *evals, double **evecs, int n)
-{
-    int                 info = 0;
-    int                 one = 1, negone = -1;
-    char                     jobvl = 'V', jobvr = 'N';
-    int                 lwork;
-    double                  *work = malloc(sizeof(double));
-    double                  *wi = NULL, *vr = NULL;
-    double                 **tmpmat = NULL;
-    double                   tmp;
-    int                      i, j;
-
-    tmpmat = MatAlloc(n, n);
-    wi = malloc(n * sizeof(double));
-    memcpy(&tmpmat[0][0], &mat[0][0], n * n * sizeof(double));
-
-/*     for (i = 0; i < n; ++i) */
-/*         for (j = 0; j < n; ++j) */
-/*             tmpmat[i][j] = mat[j][i]; */
-
-    DGEEV(&jobvl, &jobvr, &n, &tmpmat[0][0], &n, evals, wi,
-           &evecs[0][0], &n, vr, &one, work, &negone, &info);
-    lwork = work[0];
-    free(work);
-    work = malloc(lwork * sizeof(double));
-    DGEEV(&jobvl, &jobvr, &n, &tmpmat[0][0], &n, evals, wi,
-           &evecs[0][0], &n, vr, &one, work, &lwork, &info);
-
-    for (i = 0; i < n; ++i)
-    {
-        for (j = 0; j < i; ++j)
-        {
-            tmp = evecs[i][j];
-            evecs[i][j] = evecs[j][i];
-            evecs[j][i] = tmp;
-        }
-    }
-
-    free(wi);
-    free(work);
-    MatDestroy(&tmpmat);
-}
+/* void */
+/* eigenvalsym2(const double **mat, double *evals, double **evecs, int n, double *work) */
+/* { */
+/*     int                 info = 0; */
+/*     char                     jobz_v = 'N', uplo_u = 'U'; */
+/*     int                 lwork = n * n; */
+/*  */
+/*     memcpy(&evecs[0][0], &mat[0][0], n * n * sizeof(double)); */
+/*     DSYEV(&jobz_v, &uplo_u, &n, &evecs[0][0], &n, evals, work, &lwork, &info); */
+/* } */
 
 
 #define CUTOFF 15
