@@ -32,10 +32,10 @@
 #include "DLTutils.h"
 #include "Error.h"
 #include "pdbMalloc.h"
-#include "Coords.h"
-#include "PDBCoords.h"
-#include "Coords.h"
-#include "PDBCoords.h"
+#include "Cds.h"
+#include "PDBCds.h"
+#include "Cds.h"
+#include "PDBCds.h"
 #include "DLTmath.h"
 
 
@@ -137,7 +137,7 @@ Algorithm
     {
         perror("\n  ERROR");
         fprintf(stderr,
-                "\n  ERROR6: could not allocate memory in function CoordsArrayInit(). \n");
+                "\n  ERROR6: could not allocate memory in function CdsArrayInit(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
@@ -158,7 +158,7 @@ Algorithm
     algo->atoms        = 0;
     algo->reflection   = 0;
     algo->embedave     = 0; /* 2 = biased ML embedded structure */
-    algo->jackknife    = 0;
+    algo->landmarks    = 0;
     algo->writestats   = 1;
     algo->random       = 0;
     algo->pca          = 0;
@@ -181,10 +181,8 @@ Algorithm
     algo->norot        = 0;
     algo->alignment    = 0;
     algo->fmodel       = 0;
-    algo->dimweight    = 0;
     algo->covweight    = 0;
     algo->varweight    = 1;
-    algo->LedoitWolf   = 0;
     algo->hierarch     = 1;
     algo->leastsquares = 0;
     algo->filenum      = 0;
@@ -247,19 +245,19 @@ Statistics
 }
 
 
-CoordsArray
-*CoordsArrayInit(void)
+CdsArray
+*CdsArrayInit(void)
 {
-    CoordsArray *cdsA = NULL;
+    CdsArray *cdsA = NULL;
 
-    cdsA = (CoordsArray *) malloc(sizeof(CoordsArray));
+    cdsA = (CdsArray *) malloc(sizeof(CdsArray));
 /* printf("\ncdsA malloc(%p)", (void *) cdsA); */
 /* fflush(NULL); */
     if (cdsA == NULL)
     {
         perror("\n  ERROR");
         fprintf(stderr,
-                "\n  ERROR6: could not allocate memory in function CoordsArrayInit(). \n");
+                "\n  ERROR6: could not allocate memory in function CdsArrayInit(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
@@ -271,10 +269,10 @@ CoordsArray
     cdsA->pdbA = NULL;
     cdsA->scratchA = NULL;
 
-    cdsA->coords = NULL;
-    cdsA->avecoords = NULL;
-    cdsA->tcoords = NULL;
-    cdsA->jkcoords = NULL;
+    cdsA->cds = NULL;
+    cdsA->avecds = NULL;
+    cdsA->tcds = NULL;
+    cdsA->jkcds = NULL;
 
     cdsA->w = NULL;
     cdsA->var = NULL;
@@ -295,9 +293,6 @@ CoordsArray
     cdsA->MVCovMat = NULL;
     cdsA->SCovMat = NULL;
 
-    cdsA->AxCovMat = MatAlloc(3, 3);
-    cdsA->AxWtMat  = MatAlloc(3, 3);
-
     cdsA->pcamat = NULL;
     cdsA->pcavals = NULL;
     cdsA->modpcamat = NULL;
@@ -322,16 +317,16 @@ CoordsArray
 
 
 void
-CoordsArrayAllocNum(CoordsArray *cdsA, const int cnum)
+CdsArrayAllocNum(CdsArray *cdsA, const int cnum)
 {
     cdsA->cnum = cnum;
 
-    cdsA->coords = (Coords **) malloc(cnum * sizeof(Coords *));
-    if (cdsA->coords == NULL)
+    cdsA->cds = (Cds **) malloc(cnum * sizeof(Cds *));
+    if (cdsA->cds == NULL)
     {
         perror("\n  ERROR");
         fprintf(stderr,
-                "\n  ERROR6: could not allocate memory in function CoordsArrayAlloc(). \n");
+                "\n  ERROR6: could not allocate memory in function CdsArrayAlloc(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
@@ -339,7 +334,7 @@ CoordsArrayAllocNum(CoordsArray *cdsA, const int cnum)
 
 
 void
-CoordsArrayAllocLen(CoordsArray *cdsA, const int vlen)
+CdsArrayAllocLen(CdsArray *cdsA, const int vlen)
 {
     int             i;
 
@@ -347,16 +342,16 @@ CoordsArrayAllocLen(CoordsArray *cdsA, const int vlen)
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        cdsA->coords[i] = CoordsInit();
-        CoordsAlloc(cdsA->coords[i], vlen);
+        cdsA->cds[i] = CdsInit();
+        CdsAlloc(cdsA->cds[i], vlen);
     }
 
-    cdsA->avecoords = CoordsInit();
-    CoordsAlloc(cdsA->avecoords, vlen);
-    cdsA->tcoords = CoordsInit();
-    CoordsAlloc(cdsA->tcoords, vlen);
-    cdsA->jkcoords = CoordsInit();
-    CoordsAlloc(cdsA->jkcoords, vlen);
+    cdsA->avecds = CdsInit();
+    CdsAlloc(cdsA->avecds, vlen);
+    cdsA->tcds = CdsInit();
+    CdsAlloc(cdsA->tcds, vlen);
+    cdsA->jkcds = CdsInit();
+    CdsAlloc(cdsA->jkcds, vlen);
 
     cdsA->var = (double *) calloc(vlen, sizeof(double));
     cdsA->w   = (double *) calloc(vlen, sizeof(double));
@@ -365,30 +360,27 @@ CoordsArrayAllocLen(CoordsArray *cdsA, const int vlen)
 
 
 void
-CoordsArrayAlloc(CoordsArray *cdsA, const int cnum, const int vlen)
+CdsArrayAlloc(CdsArray *cdsA, const int cnum, const int vlen)
 {
-    CoordsArrayAllocNum(cdsA, cnum);
-    CoordsArrayAllocLen(cdsA, vlen);
+    CdsArrayAllocNum(cdsA, cnum);
+    CdsArrayAllocLen(cdsA, vlen);
 }
 
 
 void
-CoordsArraySetup(CoordsArray *cdsA)
+CdsArraySetup(CdsArray *cdsA)
 {
     memsetd(cdsA->var, 1.0, cdsA->vlen);
     memsetd(cdsA->w, 1.0, cdsA->vlen);
-    cdsA->AxCovMat[0][0] = cdsA->AxCovMat[1][1] = cdsA->AxCovMat[2][2] = 1.0;
-    cdsA->AxWtMat[0][0] = cdsA->AxWtMat[1][1] = cdsA->AxWtMat[2][2] = 1.0;
-    memsetd(&cdsA->axesw[0], 1.0, 3);
 }
 
 
 void
-CoordsArrayDestroy(CoordsArray **cdsA_ptr)
+CdsArrayDestroy(CdsArray **cdsA_ptr)
 {
     int             i;
 
-    CoordsArray *cdsA = *cdsA_ptr;
+    CdsArray *cdsA = *cdsA_ptr;
 
     free(cdsA->msafile_name);
     cdsA->msafile_name = NULL;
@@ -397,15 +389,15 @@ CoordsArrayDestroy(CoordsArray **cdsA_ptr)
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        CoordsDestroy(&(cdsA->coords[i]));
+        CdsDestroy(&(cdsA->cds[i]));
     }
 
-    free(cdsA->coords);
-    cdsA->coords = NULL;
+    free(cdsA->cds);
+    cdsA->cds = NULL;
 
-    CoordsDestroy(&(cdsA->avecoords));
-    CoordsDestroy(&(cdsA->tcoords));
-    CoordsDestroy(&(cdsA->jkcoords));
+    CdsDestroy(&(cdsA->avecds));
+    CdsDestroy(&(cdsA->tcds));
+    CdsDestroy(&(cdsA->jkcds));
 
     free(cdsA->stats);
     cdsA->stats = NULL;
@@ -453,7 +445,7 @@ CoordsArrayDestroy(CoordsArray **cdsA_ptr)
 
 
 void
-DistMatsAlloc(CoordsArray *cdsA)
+DistMatsAlloc(CdsArray *cdsA)
 {
     /* cdsA->Var_matrix = MatAlloc(cdsA->vlen, cdsA->vlen); */
     cdsA->Dij_matrix = MatAlloc(cdsA->vlen, cdsA->vlen);
@@ -462,7 +454,7 @@ DistMatsAlloc(CoordsArray *cdsA)
 
 
 void
-DistMatsDestroy(CoordsArray *cdsA)
+DistMatsDestroy(CdsArray *cdsA)
 {
 /*     if (cdsA->Var_matrix != NULL) */
 /*         MatDestroy(&(cdsA->Var_matrix)); */
@@ -474,7 +466,7 @@ DistMatsDestroy(CoordsArray *cdsA)
 
 
 void
-CovMatsDestroy(CoordsArray *cdsA)
+CovMatsDestroy(CdsArray *cdsA)
 {
     if (cdsA->CovMat != NULL)
         MatDestroy(&(cdsA->CovMat));
@@ -502,10 +494,6 @@ CovMatsDestroy(CoordsArray *cdsA)
         MatDestroy(&(cdsA->tmpmat3d));
     if (cdsA->MVCovMat != NULL)
         MatDestroy(&(cdsA->MVCovMat));
-    if (cdsA->AxCovMat != NULL)
-        MatDestroy(&(cdsA->AxCovMat));
-    if (cdsA->AxWtMat != NULL)
-        MatDestroy(&(cdsA->AxWtMat));
     if (cdsA->SCovMat != NULL)
         MatDestroy(&(cdsA->SCovMat));
     if (cdsA->tmpmatK3a != NULL)
@@ -518,7 +506,7 @@ CovMatsDestroy(CoordsArray *cdsA)
 
 
 void
-PCAAlloc(CoordsArray *cdsA)
+PCAAlloc(CdsArray *cdsA)
 {
     cdsA->pcamat = MatAlloc(cdsA->vlen, cdsA->vlen);
     cdsA->pcavals = malloc(cdsA->vlen * sizeof(double));
@@ -526,7 +514,7 @@ PCAAlloc(CoordsArray *cdsA)
 
 
 void
-PCADestroy(CoordsArray *cdsA)
+PCADestroy(CdsArray *cdsA)
 {
     if (cdsA->pcamat != NULL)
         MatDestroy(&(cdsA->pcamat));
@@ -538,191 +526,189 @@ PCADestroy(CoordsArray *cdsA)
 }
 
 
-Coords
-*CoordsInit(void)
+Cds
+*CdsInit(void)
 {
     int             i, j;
-    Coords         *coords = NULL;
+    Cds         *cds = NULL;
 
-    coords = (Coords *) malloc(sizeof(Coords));
+    cds = (Cds *) malloc(sizeof(Cds));
 
-    strncpy(coords->filename, "", 1);
+    strncpy(cds->filename, "", 1);
 
-    coords->resName    = NULL;
-    coords->resName_space = NULL;
-    coords->chainID    = NULL;
-    coords->resSeq     = NULL;
-    coords->x          = NULL;
-    coords->y          = NULL;
-    coords->z          = NULL;
-    coords->o          = NULL;
-    coords->b          = NULL;
-    coords->residual_x = NULL;
-    coords->residual_y = NULL;
-    coords->residual_z = NULL;
-    coords->covx       = NULL;
-    coords->covy       = NULL;
-    coords->covz       = NULL;
+    cds->resName    = NULL;
+    cds->resName_space = NULL;
+    cds->chainID    = NULL;
+    cds->resSeq     = NULL;
+    cds->x          = NULL;
+    cds->y          = NULL;
+    cds->z          = NULL;
+    cds->o          = NULL;
+    cds->b          = NULL;
+    cds->residual_x = NULL;
+    cds->residual_y = NULL;
+    cds->residual_z = NULL;
+    cds->covx       = NULL;
+    cds->covy       = NULL;
+    cds->covz       = NULL;
 
-    coords->innerprod = NULL;
-    coords->vlen = 0;
-    coords->innerprod2 = NULL;
+    cds->innerprod = NULL;
+    cds->vlen = 0;
+    cds->innerprod2 = NULL;
 
-    coords->matrix = MatAlloc(3, 3);
-    coords->last_matrix = MatAlloc(3, 3);
-    coords->evecs = MatAlloc(4,4);
-    coords->jackmat = MatAlloc(3, 3);
+    cds->matrix = MatAlloc(3, 3);
+    cds->last_matrix = MatAlloc(3, 3);
+    cds->evecs = MatAlloc(4,4);
 
     for (i = 0; i < 4; ++i)
-        coords->evecs[i][0] = 1.0;
+        cds->evecs[i][0] = 1.0;
 
     for (i = 0; i < 3; ++i)
         for (j = 0; j < 3; ++j)
-            coords->matrix[i][j] = coords->last_matrix[i][j] = 0.0;
+            cds->matrix[i][j] = cds->last_matrix[i][j] = 0.0;
 
-    coords->tmpmat3a = MatAlloc(3, 3);
-    coords->tmpmat3b = MatAlloc(3, 3);
-    coords->tmpmat3c = MatAlloc(3, 3);
-    coords->tmpmat3d = MatAlloc(3, 3);
+    cds->tmpmat3a = MatAlloc(3, 3);
+    cds->tmpmat3b = MatAlloc(3, 3);
+    cds->tmpmat3c = MatAlloc(3, 3);
+    cds->tmpmat3d = MatAlloc(3, 3);
 
-    coords->bfact_c = 1.0;
-    coords->scale = 1.0;
+    cds->bfact_c = 1.0;
+    cds->scale = 1.0;
 
-    return(coords);
+    return(cds);
 }
 
 
 void
-CoordsAlloc(Coords *coords, const int vlen)
+CdsAlloc(Cds *cds, const int vlen)
 {
     int             i;
 
-    coords->vlen = vlen;
+    cds->vlen = vlen;
 
-    coords->resName    = (char **)  calloc(vlen, sizeof(char *));
-    coords->resName_space = (char *)  calloc(4 * vlen, sizeof(char));
-    coords->chainID    = (char *)   calloc(vlen, sizeof(char));
-    coords->resSeq     = (int *)    calloc(vlen, sizeof(int));
-    coords->x          = (double *) calloc(vlen, sizeof(double));
-    coords->y          = (double *) calloc(vlen, sizeof(double));
-    coords->z          = (double *) calloc(vlen, sizeof(double));
-    coords->o          = (double *) calloc(vlen, sizeof(double));
-    coords->b          = (double *) calloc(vlen, sizeof(double));
-    coords->prvar      = (double *) calloc(vlen, sizeof(double));
-    coords->residual_x = (double *) calloc(vlen, sizeof(double));
-    coords->residual_y = (double *) calloc(vlen, sizeof(double));
-    coords->residual_z = (double *) calloc(vlen, sizeof(double));
-    coords->covx       = (double *) calloc(vlen, sizeof(double));
-    coords->covy       = (double *) calloc(vlen, sizeof(double));
-    coords->covz       = (double *) calloc(vlen, sizeof(double));
+    cds->resName    = (char **)  calloc(vlen, sizeof(char *));
+    cds->resName_space = (char *)  calloc(4 * vlen, sizeof(char));
+    cds->chainID    = (char *)   calloc(vlen, sizeof(char));
+    cds->resSeq     = (int *)    calloc(vlen, sizeof(int));
+    cds->x          = (double *) calloc(vlen, sizeof(double));
+    cds->y          = (double *) calloc(vlen, sizeof(double));
+    cds->z          = (double *) calloc(vlen, sizeof(double));
+    cds->o          = (double *) calloc(vlen, sizeof(double));
+    cds->b          = (double *) calloc(vlen, sizeof(double));
+    cds->prvar      = (double *) calloc(vlen, sizeof(double));
+    cds->residual_x = (double *) calloc(vlen, sizeof(double));
+    cds->residual_y = (double *) calloc(vlen, sizeof(double));
+    cds->residual_z = (double *) calloc(vlen, sizeof(double));
+    cds->covx       = (double *) calloc(vlen, sizeof(double));
+    cds->covy       = (double *) calloc(vlen, sizeof(double));
+    cds->covz       = (double *) calloc(vlen, sizeof(double));
 
-    if (   coords->resName       == NULL
-        || coords->resName_space == NULL
-        || coords->chainID       == NULL
-        || coords->resSeq        == NULL
-        || coords->x             == NULL
-        || coords->y             == NULL
-        || coords->z             == NULL
-        || coords->o             == NULL
-        || coords->b             == NULL
-        || coords->prvar         == NULL
-        || coords->residual_x    == NULL
-        || coords->residual_y    == NULL
-        || coords->residual_z    == NULL
-        || coords->covx          == NULL
-        || coords->covy          == NULL
-        || coords->covz          == NULL)
+    if (   cds->resName       == NULL
+        || cds->resName_space == NULL
+        || cds->chainID       == NULL
+        || cds->resSeq        == NULL
+        || cds->x             == NULL
+        || cds->y             == NULL
+        || cds->z             == NULL
+        || cds->o             == NULL
+        || cds->b             == NULL
+        || cds->prvar         == NULL
+        || cds->residual_x    == NULL
+        || cds->residual_y    == NULL
+        || cds->residual_z    == NULL
+        || cds->covx          == NULL
+        || cds->covy          == NULL
+        || cds->covz          == NULL)
     {
         perror("\n  ERROR");
-        fprintf(stderr, "\n  ERROR5: could not allocate memory in function CoordsAlloc(). \n");
+        fprintf(stderr, "\n  ERROR5: could not allocate memory in function CdsAlloc(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
 
     for (i = 0; i < vlen; ++i)
-        coords->resName[i] = coords->resName_space + (i * 4); /* 3 */
+        cds->resName[i] = cds->resName_space + (i * 4); /* 3 */
 
-    CoordsSetup(coords);
+    CdsSetup(cds);
 }
 
 
 void
-CoordsSetup(Coords *coords)
+CdsSetup(Cds *cds)
 {
     int             i;
 
-    memsetd(coords->translation, 0.0, 3);
-    memsetd(coords->jktranslation, 0.0, 3);
-    memsetd(coords->transsum, 0.0, 3);
+    memsetd(cds->translation, 0.0, 3);
+    memsetd(cds->jktranslation, 0.0, 3);
+    memsetd(cds->transsum, 0.0, 3);
 
     for (i = 0; i < 4; ++i)
-        coords->evecs[i][0] = 1.0;
+        cds->evecs[i][0] = 1.0;
 
     for (i = 0; i < 3; ++i)
-        coords->matrix[i][i] = coords->last_matrix[i][i] = 1.0;
+        cds->matrix[i][i] = cds->last_matrix[i][i] = 1.0;
 }
 
 
 void
-CoordsDestroy(Coords **coords_ptr)
+CdsDestroy(Cds **cds_ptr)
 {
-    Coords *coords = *coords_ptr;
+    Cds *cds = *cds_ptr;
 
-    free(coords->resSeq);
-    free(coords->resName_space);
-    free(coords->chainID);
-    free(coords->resName);
-    free(coords->x);
-    free(coords->y);
-    free(coords->z);
-    free(coords->o);
-    free(coords->b);
-    free(coords->prvar);
-    free(coords->residual_x);
-    free(coords->residual_y);
-    free(coords->residual_z);
-    free(coords->covx);
-    free(coords->covy);
-    free(coords->covz);
-    MatDestroy(&(coords->matrix));
-    MatDestroy(&(coords->last_matrix));
-    MatDestroy(&(coords->jackmat));
+    free(cds->resSeq);
+    free(cds->resName_space);
+    free(cds->chainID);
+    free(cds->resName);
+    free(cds->x);
+    free(cds->y);
+    free(cds->z);
+    free(cds->o);
+    free(cds->b);
+    free(cds->prvar);
+    free(cds->residual_x);
+    free(cds->residual_y);
+    free(cds->residual_z);
+    free(cds->covx);
+    free(cds->covy);
+    free(cds->covz);
+    MatDestroy(&(cds->matrix));
+    MatDestroy(&(cds->last_matrix));
 
-    if (coords->innerprod != NULL)
-        MatDestroy(&(coords->innerprod));
+    if (cds->innerprod != NULL)
+        MatDestroy(&(cds->innerprod));
 
-    if (coords->innerprod2 != NULL)
-        MatDestroy(&(coords->innerprod2));
+    if (cds->innerprod2 != NULL)
+        MatDestroy(&(cds->innerprod2));
 
-    MatDestroy(&(coords->evecs));
+    MatDestroy(&(cds->evecs));
 
-    MatDestroy(&(coords->tmpmat3a));
-    MatDestroy(&(coords->tmpmat3b));
-    MatDestroy(&(coords->tmpmat3c));
-    MatDestroy(&(coords->tmpmat3d));
+    MatDestroy(&(cds->tmpmat3a));
+    MatDestroy(&(cds->tmpmat3b));
+    MatDestroy(&(cds->tmpmat3c));
+    MatDestroy(&(cds->tmpmat3d));
 
-    free(coords);
-    *coords_ptr = NULL;
+    free(cds);
+    *cds_ptr = NULL;
 }
 
 
-PDBCoordsArray
-*PDBCoordsArrayInit(void)
+PDBCdsArray
+*PDBCdsArrayInit(void)
 {
-    PDBCoordsArray *pdbA = NULL; 
+    PDBCdsArray *pdbA = NULL; 
 
-    pdbA = (PDBCoordsArray *) malloc(sizeof(PDBCoordsArray));
+    pdbA = (PDBCdsArray *) malloc(sizeof(PDBCdsArray));
     if (pdbA == NULL)
     {
         perror("\n  ERROR");
         fprintf(stderr,
-                "\n  ERROR6: could not allocate memory in function PDBCoordsArrayAlloc(). \n");
+                "\n  ERROR6: could not allocate memory in function PDBCdsArrayAlloc(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
 
-    pdbA->coords = NULL;
-    pdbA->avecoords = NULL;
+    pdbA->cds = NULL;
+    pdbA->avecds = NULL;
     pdbA->upper = NULL;
     pdbA->lower = NULL;
     pdbA->scratchA = NULL;
@@ -734,39 +720,39 @@ PDBCoordsArray
 
 
 void
-PDBCoordsArrayAlloc(PDBCoordsArray *pdbA, const int cnum, const int vlen)
+PDBCdsArrayAlloc(PDBCdsArray *pdbA, const int cnum, const int vlen)
 {
-    PDBCoordsArrayAllocNum(pdbA, cnum);
-    PDBCoordsArrayAllocLen(pdbA, vlen);
+    PDBCdsArrayAllocNum(pdbA, cnum);
+    PDBCdsArrayAllocLen(pdbA, vlen);
 }
 
 
 void
-PDBCoordsArrayAllocNum(PDBCoordsArray *pdbA, const int cnum)
+PDBCdsArrayAllocNum(PDBCdsArray *pdbA, const int cnum)
 {
     int             i;
 
-    pdbA->coords = (PDBCoords **) malloc(cnum * sizeof(PDBCoords *));
+    pdbA->cds = (PDBCds **) malloc(cnum * sizeof(PDBCds *));
     pdbA->cnum = cnum;
 
     for (i = 0; i < cnum; ++i)
-        pdbA->coords[i] = PDBCoordsInit();
+        pdbA->cds[i] = PDBCdsInit();
 
-    pdbA->avecoords = PDBCoordsInit();
+    pdbA->avecds = PDBCdsInit();
 }
 
 
 void
-PDBCoordsArrayAllocLen(PDBCoordsArray *pdbA, const int vlen)
+PDBCdsArrayAllocLen(PDBCdsArray *pdbA, const int vlen)
 {
     int             i;
 
     if (pdbA == NULL
-        || pdbA->coords == NULL)
+        || pdbA->cds == NULL)
     {
         perror("\n  ERROR");
         fprintf(stderr,
-                "\n  ERROR6: could not allocate memory in function PDBCoordsArrayAlloc(). \n");
+                "\n  ERROR6: could not allocate memory in function PDBCdsArrayAlloc(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
@@ -775,24 +761,24 @@ PDBCoordsArrayAllocLen(PDBCoordsArray *pdbA, const int vlen)
 
     for (i = 0; i < pdbA->cnum; ++i)
     {
-        if (pdbA->coords[i]->vlen == 0) /* only allocate if it needs it */
-            PDBCoordsAlloc(pdbA->coords[i], vlen);
+        if (pdbA->cds[i]->vlen == 0) /* only allocate if it needs it */
+            PDBCdsAlloc(pdbA->cds[i], vlen);
     }
 
-    PDBCoordsAlloc(pdbA->avecoords, vlen);
+    PDBCdsAlloc(pdbA->avecds, vlen);
 }
 
 
 void
-PDBCoordsArrayDestroy(PDBCoordsArray **pdbA_ptr)
+PDBCdsArrayDestroy(PDBCdsArray **pdbA_ptr)
 {
-    PDBCoordsArray *pdbA = *pdbA_ptr;
+    PDBCdsArray *pdbA = *pdbA_ptr;
     int             i;
 
     for (i = 0; i < pdbA->cnum; ++i)
-        PDBCoordsDestroy(&(pdbA->coords[i]));
+        PDBCdsDestroy(&(pdbA->cds[i]));
 
-    PDBCoordsDestroy(&(pdbA->avecoords));
+    PDBCdsDestroy(&(pdbA->avecds));
 
     if (pdbA->upper != NULL)
         free(pdbA->upper);
@@ -803,141 +789,141 @@ PDBCoordsArrayDestroy(PDBCoordsArray **pdbA_ptr)
     if (pdbA->seq2pdb != NULL)
         Seq2pdbDestroy(&(pdbA->seq2pdb));
 
-    free(pdbA->coords);
+    free(pdbA->cds);
     free(pdbA);
 
     *pdbA_ptr = NULL;
 }
 
 
-PDBCoords
-*PDBCoordsInit(void)
+PDBCds
+*PDBCdsInit(void)
 {
-    PDBCoords      *pdbcoords = NULL;
+    PDBCds      *pdbcds = NULL;
 
-    pdbcoords = (PDBCoords *) malloc(sizeof(PDBCoords));
-    pdbcoords->vlen = 0; /* so that we know later if this has been allocated or not */
-    pdbcoords->translation = calloc(3, sizeof(double));
-    pdbcoords->matrix = MatAlloc(3, 3);
-    memset(&pdbcoords->matrix[0][0], 0, 9 * sizeof(double));
+    pdbcds = (PDBCds *) malloc(sizeof(PDBCds));
+    pdbcds->vlen = 0; /* so that we know later if this has been allocated or not */
+    pdbcds->translation = calloc(3, sizeof(double));
+    pdbcds->matrix = MatAlloc(3, 3);
+    memset(&pdbcds->matrix[0][0], 0, 9 * sizeof(double));
 
-    return(pdbcoords);
+    return(pdbcds);
 }
 
 
 void
-PDBCoordsAlloc(PDBCoords *pdbcoords, const int vlen)
+PDBCdsAlloc(PDBCds *pdbcds, const int vlen)
 {
     int             i;
 
-    pdbcoords->vlen = vlen;
+    pdbcds->vlen = vlen;
 
     /* allocate memory for the pointers to the fields */
-    pdbcoords->record     = (char **)  calloc(vlen, sizeof(char *));
-    pdbcoords->serial     = (unsigned int *) calloc(vlen, sizeof(unsigned int));
-    pdbcoords->Hnum       = (char *)   calloc(vlen, sizeof(char));
-    pdbcoords->name       = (char **)  calloc(vlen, sizeof(char *));
-    pdbcoords->altLoc     = (char *)   calloc(vlen, sizeof(char));
-    pdbcoords->resName    = (char **)  calloc(vlen, sizeof(char *));
-    pdbcoords->xchainID   = (char *)   calloc(vlen, sizeof(char));
-    pdbcoords->chainID    = (char *)   calloc(vlen, sizeof(char));
-    pdbcoords->resSeq     = (int *)    calloc(vlen, sizeof(int));
-    pdbcoords->iCode      = (char *)   calloc(vlen, sizeof(char));
-    pdbcoords->x          = (double *) calloc(vlen, sizeof(double));
-    pdbcoords->y          = (double *) calloc(vlen, sizeof(double));
-    pdbcoords->z          = (double *) calloc(vlen, sizeof(double));
-    pdbcoords->occupancy  = (double *) calloc(vlen, sizeof(double));
-    pdbcoords->tempFactor = (double *) calloc(vlen, sizeof(double));
-    pdbcoords->segID      = (char **)  calloc(vlen, sizeof(char *));
-    pdbcoords->element    = (char **)  calloc(vlen, sizeof(char *));
-    pdbcoords->charge     = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->record     = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->serial     = (unsigned int *) calloc(vlen, sizeof(unsigned int));
+    pdbcds->Hnum       = (char *)   calloc(vlen, sizeof(char));
+    pdbcds->name       = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->altLoc     = (char *)   calloc(vlen, sizeof(char));
+    pdbcds->resName    = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->xchainID   = (char *)   calloc(vlen, sizeof(char));
+    pdbcds->chainID    = (char *)   calloc(vlen, sizeof(char));
+    pdbcds->resSeq     = (int *)    calloc(vlen, sizeof(int));
+    pdbcds->iCode      = (char *)   calloc(vlen, sizeof(char));
+    pdbcds->x          = (double *) calloc(vlen, sizeof(double));
+    pdbcds->y          = (double *) calloc(vlen, sizeof(double));
+    pdbcds->z          = (double *) calloc(vlen, sizeof(double));
+    pdbcds->occupancy  = (double *) calloc(vlen, sizeof(double));
+    pdbcds->tempFactor = (double *) calloc(vlen, sizeof(double));
+    pdbcds->segID      = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->element    = (char **)  calloc(vlen, sizeof(char *));
+    pdbcds->charge     = (char **)  calloc(vlen, sizeof(char *));
 
     /* allocate space for the fields in total */
-    pdbcoords->record_space  = (char *)  calloc(8 * vlen, sizeof(char));
-    pdbcoords->name_space    = (char *)  calloc(4 * vlen, sizeof(char));
-    pdbcoords->resName_space = (char *)  calloc(4 * vlen, sizeof(char));
-    pdbcoords->segID_space   = (char *)  calloc(8 * vlen, sizeof(char));
-    pdbcoords->element_space = (char *)  calloc(4 * vlen, sizeof(char));
-    pdbcoords->charge_space  = (char *)  calloc(4 * vlen, sizeof(char));
+    pdbcds->record_space  = (char *)  calloc(8 * vlen, sizeof(char));
+    pdbcds->name_space    = (char *)  calloc(4 * vlen, sizeof(char));
+    pdbcds->resName_space = (char *)  calloc(4 * vlen, sizeof(char));
+    pdbcds->segID_space   = (char *)  calloc(8 * vlen, sizeof(char));
+    pdbcds->element_space = (char *)  calloc(4 * vlen, sizeof(char));
+    pdbcds->charge_space  = (char *)  calloc(4 * vlen, sizeof(char));
 
-    if (   pdbcoords->record        == NULL
-        || pdbcoords->serial        == NULL
-        || pdbcoords->Hnum          == NULL
-        || pdbcoords->name          == NULL
-        || pdbcoords->altLoc        == NULL
-        || pdbcoords->resName       == NULL
-        || pdbcoords->xchainID      == NULL
-        || pdbcoords->chainID       == NULL
-        || pdbcoords->resSeq        == NULL
-        || pdbcoords->iCode         == NULL
-        || pdbcoords->x             == NULL
-        || pdbcoords->y             == NULL
-        || pdbcoords->z             == NULL
-        || pdbcoords->occupancy     == NULL
-        || pdbcoords->tempFactor    == NULL
-        || pdbcoords->segID         == NULL
-        || pdbcoords->element       == NULL
-        || pdbcoords->charge        == NULL
-        || pdbcoords->record_space  == NULL
-        || pdbcoords->name_space    == NULL
-        || pdbcoords->resName_space == NULL
-        || pdbcoords->segID_space   == NULL
-        || pdbcoords->element_space == NULL
-        || pdbcoords->charge_space  == NULL)
+    if (   pdbcds->record        == NULL
+        || pdbcds->serial        == NULL
+        || pdbcds->Hnum          == NULL
+        || pdbcds->name          == NULL
+        || pdbcds->altLoc        == NULL
+        || pdbcds->resName       == NULL
+        || pdbcds->xchainID      == NULL
+        || pdbcds->chainID       == NULL
+        || pdbcds->resSeq        == NULL
+        || pdbcds->iCode         == NULL
+        || pdbcds->x             == NULL
+        || pdbcds->y             == NULL
+        || pdbcds->z             == NULL
+        || pdbcds->occupancy     == NULL
+        || pdbcds->tempFactor    == NULL
+        || pdbcds->segID         == NULL
+        || pdbcds->element       == NULL
+        || pdbcds->charge        == NULL
+        || pdbcds->record_space  == NULL
+        || pdbcds->name_space    == NULL
+        || pdbcds->resName_space == NULL
+        || pdbcds->segID_space   == NULL
+        || pdbcds->element_space == NULL
+        || pdbcds->charge_space  == NULL)
     {
         perror("\n  ERROR");
-        fprintf(stderr, "\n  ERROR7: could not allocate memory in function PDBCoordsAlloc(). \n");
+        fprintf(stderr, "\n  ERROR7: could not allocate memory in function PDBCdsAlloc(). \n");
         PrintTheseusTag();
         exit(EXIT_FAILURE);
     }
 
     /*  now 'point' the pointers */
-    for (i = 0; i < pdbcoords->vlen; ++i)
+    for (i = 0; i < pdbcds->vlen; ++i)
     {
-        pdbcoords->record[i]  = pdbcoords->record_space  + (i * 8); /* 6 */
-        pdbcoords->name[i]    = pdbcoords->name_space    + (i * 4); /* 3 */
-        pdbcoords->resName[i] = pdbcoords->resName_space + (i * 4); /* 3 */
-        pdbcoords->segID[i]   = pdbcoords->segID_space   + (i * 8); /* 4 */
-        pdbcoords->element[i] = pdbcoords->element_space + (i * 4); /* 2 */
-        pdbcoords->charge[i]  = pdbcoords->charge_space  + (i * 4); /* 2 */
+        pdbcds->record[i]  = pdbcds->record_space  + (i * 8); /* 6 */
+        pdbcds->name[i]    = pdbcds->name_space    + (i * 4); /* 3 */
+        pdbcds->resName[i] = pdbcds->resName_space + (i * 4); /* 3 */
+        pdbcds->segID[i]   = pdbcds->segID_space   + (i * 8); /* 4 */
+        pdbcds->element[i] = pdbcds->element_space + (i * 4); /* 2 */
+        pdbcds->charge[i]  = pdbcds->charge_space  + (i * 4); /* 2 */
     }
 }
 
 
 void
-PDBCoordsDestroy(PDBCoords **pdbcoords_ptr)
+PDBCdsDestroy(PDBCds **pdbcds_ptr)
 {
-    PDBCoords *pdbcoords = *pdbcoords_ptr;
+    PDBCds *pdbcds = *pdbcds_ptr;
 
-    free(pdbcoords->record_space);
-    free(pdbcoords->name_space);
-    free(pdbcoords->resName_space);
-    free(pdbcoords->segID_space);
-    free(pdbcoords->element_space);
-    free(pdbcoords->charge_space);
+    free(pdbcds->record_space);
+    free(pdbcds->name_space);
+    free(pdbcds->resName_space);
+    free(pdbcds->segID_space);
+    free(pdbcds->element_space);
+    free(pdbcds->charge_space);
 
-    MatDestroy(&(pdbcoords->matrix));
-    free(pdbcoords->translation);
+    MatDestroy(&(pdbcds->matrix));
+    free(pdbcds->translation);
 
-    free(pdbcoords->record);
-    free(pdbcoords->serial);
-    free(pdbcoords->Hnum);
-    free(pdbcoords->name);
-    free(pdbcoords->altLoc);
-    free(pdbcoords->resName);
-    free(pdbcoords->xchainID);
-    free(pdbcoords->chainID);
-    free(pdbcoords->resSeq);
-    free(pdbcoords->iCode);
-    free(pdbcoords->x);
-    free(pdbcoords->y);
-    free(pdbcoords->z);
-    free(pdbcoords->occupancy);
-    free(pdbcoords->tempFactor);
-    free(pdbcoords->segID);
-    free(pdbcoords->element);
-    free(pdbcoords->charge);
+    free(pdbcds->record);
+    free(pdbcds->serial);
+    free(pdbcds->Hnum);
+    free(pdbcds->name);
+    free(pdbcds->altLoc);
+    free(pdbcds->resName);
+    free(pdbcds->xchainID);
+    free(pdbcds->chainID);
+    free(pdbcds->resSeq);
+    free(pdbcds->iCode);
+    free(pdbcds->x);
+    free(pdbcds->y);
+    free(pdbcds->z);
+    free(pdbcds->occupancy);
+    free(pdbcds->tempFactor);
+    free(pdbcds->segID);
+    free(pdbcds->element);
+    free(pdbcds->charge);
 
-    free(pdbcoords);
-    *pdbcoords_ptr = NULL;
+    free(pdbcds);
+    *pdbcds_ptr = NULL;
 }
