@@ -61,9 +61,9 @@ gsl_rng                *r2;
     static double           start_time, end_time;
 #endif
 
-/* global declarations necessary for leave(), I think */
-CoordsArray    *baseA = NULL; /* main array of selected pdb coords, never modified after read */
-PDBCoordsArray *pdbA = NULL; /* array holding all of the pdb file coordinate info, 
+/* global declarations (necessary for leave(), I think) */
+CdsArray    *baseA = NULL; /* main array of selected pdb cds, never modified after read */
+PDBCdsArray *pdbA = NULL; /* array holding all of the pdb file coordinate info, 
                                 much of it unused in the actual calculations */
 
 static void
@@ -79,11 +79,11 @@ int
 ConvertLele(char *fp_name, const int dim, const int forms, const int lmarks);
 
 void
-WriteLeleModelFile(PDBCoordsArray *pdbAr);
+WriteLeleModelFile(PDBCdsArray *pdbAr);
 
 
 void
-testcrush(CoordsArray *cdsA)
+testcrush(CdsArray *cdsA)
 {
     int         i, j, m, n;
 
@@ -91,9 +91,9 @@ testcrush(CoordsArray *cdsA)
     {
         for (j = 0; j < i; ++j)
         {
-            for (m = 0; m < cdsA->coords[i]->vlen; ++m)
-                for (n = 0; n < cdsA->coords[j]->vlen; ++n)
-                    log(SqrCoordsDist(cdsA->coords[i], m, cdsA->coords[j], n));
+            for (m = 0; m < cdsA->cds[i]->vlen; ++m)
+                for (n = 0; n < cdsA->cds[j]->vlen; ++n)
+                    log(SqrCdsDist(cdsA->cds[i], m, cdsA->cds[j], n));
         }
     }
 }
@@ -127,7 +127,7 @@ main(int argc, char *argv[])
 //        printf("\n  WARNING2: could not set core limit size to 0. \n\n");
 //#endif
 
-    baseA = CoordsArrayInit();
+    baseA = CdsArrayInit();
     algo = baseA->algo;
     stats = baseA->stats;
     ParseCmdLine(argc, argv, baseA);
@@ -151,8 +151,8 @@ main(int argc, char *argv[])
 
     if (algo->convlele > 0)
     {
-        ConvertDryden(algo->infiles[0], 2, algo->iterations /* # coordinates/forms */, algo->jackknife /* # of landmarks */);
-        //ConvertLele_freeform(algo->infiles[0], 3, algo->iterations /* # coordinates/forms */, algo->jackknife /* # of landmarks */);
+        ConvertDryden(algo->infiles[0], 2, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
+        //ConvertLele_freeform(algo->infiles[0], 3, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
         PrintTheseusTag();
         exit(EXIT_SUCCESS);
     }
@@ -168,43 +168,43 @@ main(int argc, char *argv[])
         {
             strcat(algo->rootname, "_rand");
             //printf("\nfmodel\n = %d", algo->fmodel);
-            pdbA = GetPDBCoords(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
+            pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
 //             if (algo->fmodel == 1)
 //             {
-//                 pdbA = MakeRandPDBCoords(algo->iterations, /* # coordinates/forms */
-//                                          algo->jackknife, /* # of landmarks */
+//                 pdbA = MakeRandPDBCds(algo->iterations, /* # coordinates/forms */
+//                                          algo->landmarks, /* # of landmarks */
 //                                          &algo->radii[0], r2);
 //             }
 //             else
 //             {
-//                 pdbA = GetRandPDBCoords(algo->infiles[0], algo->iterations /* # coordinates/forms */, algo->jackknife /* # of landmarks */);
+//                 pdbA = GetRandPDBCds(algo->infiles[0], algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
 //             }
 
-            pdbA->vlen = pdbA->coords[0]->vlen;
-            PDBCoordsArrayAllocLen(pdbA, pdbA->vlen);
-            GetCoordsSelection(baseA, pdbA);
+            pdbA->vlen = pdbA->cds[0]->vlen;
+            PDBCdsArrayAllocLen(pdbA, pdbA->vlen);
+            GetCdsSelection(baseA, pdbA);
             //printf("HERE2\n\n"); fflush(NULL);
 
-            RandCoords_2sdf(baseA, r2);
-            memcpy(baseA->avecoords->resSeq, baseA->coords[0]->resSeq, baseA->vlen * sizeof(int));
-            memcpy(baseA->avecoords->chainID, baseA->coords[0]->chainID, baseA->vlen * sizeof(char));
-            memcpy(baseA->avecoords->resName_space, baseA->coords[0]->resName_space, baseA->vlen * 4 * sizeof(char));
-            AveCoords(baseA);
+            RandCds_2sdf(baseA, r2);
+            memcpy(baseA->avecds->resSeq, baseA->cds[0]->resSeq, baseA->vlen * sizeof(int));
+            memcpy(baseA->avecds->chainID, baseA->cds[0]->chainID, baseA->vlen * sizeof(char));
+            memcpy(baseA->avecds->resName_space, baseA->cds[0]->resName_space, baseA->vlen * 4 * sizeof(char));
+            AveCds(baseA);
 
             for (i = 0; i < baseA->cnum; ++i)
-                CopyCoords2PDB(pdbA->coords[i], baseA->coords[i]);
+                CopyCds2PDB(pdbA->cds[i], baseA->cds[i]);
 
             printf("    Writing CA coordinates of random structures ... \n");
             fflush(NULL);
             sup_name = mystrcat(algo->rootname, "_sup.pdb");
             WriteTheseusModelFile(pdbA, algo, stats, sup_name);
 
-            CopyCoords2PDB(pdbA->avecoords, baseA->avecoords);
+            CopyCds2PDB(pdbA->avecds, baseA->avecds);
 
             printf("    Writing CA coordinates of average of random structures ... \n");
             fflush(NULL);
             ave_name = mystrcat(algo->rootname, "_ave.pdb");
-            WriteAvePDBCoordsFile(pdbA, ave_name);
+            WriteAvePDBCdsFile(pdbA, ave_name);
 
             printf("    Calculating statistics of random structures ... \n");
             fflush(NULL);
@@ -213,13 +213,13 @@ main(int argc, char *argv[])
             PrintSuperposStats(baseA);
         }
 
-        RandRotCoordsArray(baseA, r2);
-        /* RandTransCoordsArray(baseA, 0.004); */
+        RandRotCdsArray(baseA, r2);
+        /* RandTransCdsArray(baseA, 0.004); */
         printf("    Writing CA coordinates of transformed random structures ... \n");
         fflush(NULL);
 
         for (i = 0; i < baseA->cnum; ++i)
-            CopyCoords2PDB(pdbA->coords[i], baseA->coords[i]);
+            CopyCds2PDB(pdbA->cds[i], baseA->cds[i]);
 
         transf_name = mystrcat(algo->rootname, "_transf.pdb");
         WriteTheseusModelFile(pdbA, algo, stats, transf_name);
@@ -227,19 +227,19 @@ main(int argc, char *argv[])
 
         PrintTheseusTag();
 
-/*      CoordsArrayDestroy(&baseA); */
-/*      PDBCoordsArrayDestroy(&pdbA); */
+/*      CdsArrayDestroy(&baseA); */
+/*      PDBCdsArrayDestroy(&pdbA); */
 
         exit(EXIT_SUCCESS);
     }
 
-    /* read the PDB files, putting full coords in pdbA */
+    /* read the PDB files, putting full cds in pdbA */
     if (algo->binary == 2 || algo->binary == 4)
     {
         printf("    Reading binary pdb file ... \n");
         fflush(NULL);
 
-        pdbA = ReadBinPDBCoordsArray(algo->infiles[0]);
+        pdbA = ReadBinPDBCdsArray(algo->infiles[0]);
     }
     else
     {
@@ -249,15 +249,15 @@ main(int argc, char *argv[])
             printf("    Reading %d pdb files ... \n", algo->filenum);
         fflush(NULL);
 
-        pdbA = GetPDBCoords(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
-        /* PrintPDBCoords(stdout, pdbA->coords[0]); */
+        pdbA = GetPDBCds(algo->infiles, algo->filenum, algo->fmodel, algo->atom_names);
+        /* PrintPDBCds(stdout, pdbA->cds[0]); */
     }
 
     if (algo->fasta == 1)
     {
         if (pdbA->cnum < 1)
         {
-            printf("\n  -> Found no PDB coords. Could not determine a sequence. <- \n");
+            printf("\n  -> Found no PDB cds. Could not determine a sequence. <- \n");
             Usage(0);
             exit(EXIT_FAILURE);
         }
@@ -270,7 +270,7 @@ main(int argc, char *argv[])
 
     if (pdbA->cnum < 2)
     {
-        printf("\n  -> Found less than two PDB coords. Could not do superposition. <- \n");
+        printf("\n  -> Found less than two PDB cds. Could not do superposition. <- \n");
         Usage(0);
         exit(EXIT_FAILURE);
     }
@@ -282,7 +282,7 @@ main(int argc, char *argv[])
         printf("    Writing binary coordinates file ... \n");
         fflush(NULL);
 
-        WriteBinPDBCoordsArray(pdbA);
+        WriteBinPDBCdsArray(pdbA);
         PrintTheseusTag();
         exit(EXIT_SUCCESS);
     }
@@ -292,16 +292,16 @@ main(int argc, char *argv[])
         fflush(NULL);
 
         Align2MSA(pdbA, baseA, baseA->msafile_name, baseA->mapfile_name);
-        PDBCoordsArrayAllocLen(pdbA, baseA->vlen);
+        PDBCdsArrayAllocLen(pdbA, baseA->vlen);
     }
     else
     {
         printf("    Selecting coordinates for superposition ... \n");
         fflush(NULL);
 
-        pdbA->vlen = NMRCheckPDBCoordsArray(pdbA);
-        PDBCoordsArrayAllocLen(pdbA, pdbA->vlen);
-        GetCoordsSelection(baseA, pdbA);
+        pdbA->vlen = NMRCheckPDBCdsArray(pdbA);
+        PDBCdsArrayAllocLen(pdbA, pdbA->vlen);
+        GetCdsSelection(baseA, pdbA);
     }
 
     baseA->pdbA = pdbA;
@@ -317,21 +317,17 @@ main(int argc, char *argv[])
 
     if (algo->random == '0')
     {
-        RandRotCoordsArray(baseA, r2);
-        RandTransCoordsArray(baseA, 0.1, r2);
+        RandRotCdsArray(baseA, r2);
+        RandTransCdsArray(baseA, 0.1, r2);
         printf("    Writing CA coordinates of transformed random structures ... \n");
         fflush(NULL);
         for (i = 0; i < baseA->cnum; ++i)
-            CopyCoords2PDB(pdbA->coords[i], baseA->coords[i]);
+            CopyCds2PDB(pdbA->cds[i], baseA->cds[i]);
         rand_transf_name = mystrcat(algo->rootname, "_rand_transf.pdb");
         WriteTheseusModelFile(pdbA, algo, stats, rand_transf_name);
     }
 
-    if (algo->jackknife > 0)
-    {
-        SuperJack(baseA);
-    }
-    else if (algo->FragDist > 0)
+    if (algo->FragDist > 0)
     {
         printf("    FUUUUCCCKKKK!!!!!!!!! %d \n", algo->FragDist);
         fflush(NULL);
@@ -395,7 +391,7 @@ main(int argc, char *argv[])
 /*         fputc('\n', stdout); */
 /*         for (i = 0; i < baseA->vlen; ++i) */
 /*              printf("  atom[%4d] weight =  %f, variance = %f, \n", */
-/*                     baseA->coords[0]->resSeq[i], baseA->w[i], baseA->var[i]); */
+/*                     baseA->cds[0]->resSeq[i], baseA->w[i], baseA->var[i]); */
 /*     } */
 
     PrintSuperposStats(baseA);
@@ -408,20 +404,20 @@ main(int argc, char *argv[])
         if (algo->atoms == 2) /* 2 = all atoms */
         {
             for (j = 0; j < baseA->cnum; ++j)
-                memcpy(pdbA->coords[j]->tempFactor, baseA->avecoords->b, baseA->vlen * sizeof(double));
+                memcpy(pdbA->cds[j]->tempFactor, baseA->avecds->b, baseA->vlen * sizeof(double));
         }
 
         for (i = 0; i < pdbA->cnum; ++i)
         {
-            Mat3Cpy(pdbA->coords[i]->matrix, (const double **) baseA->coords[i]->matrix);
-            memcpy(pdbA->coords[i]->translation, baseA->coords[i]->translation, 3 * sizeof(double));
+            Mat3Cpy(pdbA->cds[i]->matrix, (const double **) baseA->cds[i]->matrix);
+            memcpy(pdbA->cds[i]->translation, baseA->cds[i]->translation, 3 * sizeof(double));
         }
 
-        Mat3Cpy(pdbA->avecoords->matrix, (const double **) baseA->avecoords->matrix);
-        memcpy(pdbA->avecoords->translation, baseA->avecoords->translation, 3 * sizeof(double));
+        Mat3Cpy(pdbA->avecds->matrix, (const double **) baseA->avecds->matrix);
+        memcpy(pdbA->avecds->translation, baseA->avecds->translation, 3 * sizeof(double));
 
         for (i = 0; i < pdbA->cnum; ++i)
-            TransformPDBCoordsIp(pdbA->coords[i]);
+            TransformPDBCdsIp(pdbA->cds[i]);
 
         if (algo->fullpca == 1 && algo->alignment == 0)
         {
@@ -456,10 +452,10 @@ main(int argc, char *argv[])
                 double          olve;
                 for (i = 0; i < pdbA->cnum; ++i)
                 {
-                    for (j = 0; j < pdbA->coords[i]->vlen; ++j)
+                    for (j = 0; j < pdbA->cds[i]->vlen; ++j)
                     {
-                        sscanf(pdbA->coords[i]->segID[j], "%4lf", &olve);
-                        pdbA->coords[i]->tempFactor[j] = olve / 100.0;
+                        sscanf(pdbA->cds[i]->segID[j], "%4lf", &olve);
+                        pdbA->cds[i]->tempFactor[j] = olve / 100.0;
                     }
                 }
             }
@@ -479,37 +475,36 @@ main(int argc, char *argv[])
             printf("    Writing transformed coordinates binary file ... \n");
             fflush(NULL);
 
-            WriteBinPDBCoordsArray(pdbA);
+            WriteBinPDBCdsArray(pdbA);
         }
 
         printf("    Writing average coordinate file ... \n");
         fflush(NULL);
 
-        TransformCoordsIp(baseA->avecoords);
-        CopyCoords2PDB(pdbA->avecoords, baseA->avecoords);
+        TransformCdsIp(baseA->avecds);
+        CopyCds2PDB(pdbA->avecds, baseA->avecds);
         ave_name = mystrcat(algo->rootname, "_ave.pdb");
-        WriteAvePDBCoordsFile(pdbA, ave_name);
+        WriteAvePDBCdsFile(pdbA, ave_name);
 
-        if (baseA->avecoords->innerprod == NULL)
-            baseA->avecoords->innerprod = MatAlloc(baseA->vlen, baseA->vlen);
+        if (baseA->avecds->innerprod == NULL)
+            baseA->avecds->innerprod = MatAlloc(baseA->vlen, baseA->vlen);
 
         if (algo->ipmat == 1)
         {
 			printf("    Writing mean inner product file ... \n");
 			fflush(NULL);
 
-			CenMass(baseA->avecoords);
-			ApplyCenterIp(baseA->avecoords);
-            CoordsInnerProd(baseA->avecoords);
+			CenMass(baseA->avecds);
+			ApplyCenterIp(baseA->avecds);
+            CdsInnerProd(baseA->avecds);
             mean_ip_name = mystrcat(algo->rootname, "_mean_ip.mat");
-            PrintCovMatGnuPlot((const double **) baseA->avecoords->innerprod, baseA->vlen, mean_ip_name);
+            PrintCovMatGnuPlot((const double **) baseA->avecds->innerprod, baseA->vlen, mean_ip_name);
         }
 
-        sup_var_name = mystrcat(algo->rootname, "_sup_var.pdb");
-        Align2Vars(pdbA, baseA);
-
         if (algo->alignment == 1)
         {
+            sup_var_name = mystrcat(algo->rootname, "_sup_var.pdb");
+            Align2Vars(pdbA, baseA);
             WriteTheseusModelFile(pdbA, algo, stats, sup_var_name);
             strcat(algo->rootname, "_var");
             WriteTheseusPDBFiles(pdbA, algo, stats);
@@ -528,9 +523,9 @@ main(int argc, char *argv[])
 /*     {i=0; */
 /*         for (j = 0; j < baseA->vlen; ++j) */
 /*         { */
-/*             xx = baseA->coords[i]->x[j]; */
-/*             yy = baseA->coords[i]->y[j]; */
-/*             zz = baseA->coords[i]->z[j]; */
+/*             xx = baseA->cds[i]->x[j]; */
+/*             yy = baseA->cds[i]->y[j]; */
+/*             zz = baseA->cds[i]->z[j]; */
 /*             vv = vsum / baseA->var[j]; */
 /*             vv=1.0; */
 /*             //fprintf(fp, "%8.3e\n", xx*xx+yy*yy+zz*zz); */
@@ -544,8 +539,8 @@ main(int argc, char *argv[])
 
     PrintTheseusTag();
 
-    CoordsArrayDestroy(&baseA);
-    PDBCoordsArrayDestroy(&pdbA);
+    CdsArrayDestroy(&baseA);
+    PDBCdsArrayDestroy(&pdbA);
 
     if (sup_name != NULL)
         free(sup_name);
@@ -567,7 +562,7 @@ main(int argc, char *argv[])
 
 
 static void
-ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
+ParseCmdLine(int argc, char *argv[], CdsArray *bseA)
 {
     int            option;
     extern char   *optarg;
@@ -600,7 +595,7 @@ ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
     /*  */
     while ((option = getopt(argc, argv, "a:A:b:B:cCd:D:e:EfFg:GhHi:Ij:Jk:K:lLm:M:nNo:Op:P:q:Qr:R:s:S:tT:uUvVw:WxXyYz:Z0123:4:56789")) != -1)
     {
-        switch (option) /* See Algorithm structure in Coords.h for explanations of these flags/options */
+        switch (option) /* See Algorithm structure in Cds.h for explanations of these flags/options */
         {
             case '0': /* don't do translations */
                 algo->notrans = 1;
@@ -696,8 +691,6 @@ ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
                 algo->covweight = 1;
                 algo->varweight = 0;
                 algo->leastsquares = 0;
-                if (algo->LedoitWolf == -1) /* if user hasn't set it, default is 1 */
-                    algo->LedoitWolf = 1;
                 break;
             case 'C':
                 algo->cormat = 0;
@@ -751,8 +744,8 @@ ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
                 algo->info = 1;
                 break;
             case 'j':
-                algo->jackknife = (int) strtol(optarg, NULL, 10);
-                break;
+                algo->landmarks = (int) strtol(optarg, NULL, 10);
+            //    break;
             case 'J': /* very expert options help message */
                 Usage(2);
                 exit(EXIT_SUCCESS);
@@ -767,12 +760,9 @@ ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
                 algo->leastsquares = 1;
                 algo->varweight = 0;
                 algo->hierarch = 0;
-                algo->LedoitWolf = 0;
                 break;
             case 'L':
                 algo->instfile = 1;
-//                if (isdigit(optarg[0]))
-//                    algo->LedoitWolf = (int) strtol(optarg, NULL, 10);
                 break;
             case 'm':
                 if (isdigit(optarg[0]))
@@ -926,7 +916,7 @@ ParseCmdLine(int argc, char *argv[], CoordsArray *bseA)
 
 
 void
-PrintSuperposStats(CoordsArray *cdsA)
+PrintSuperposStats(CdsArray *cdsA)
 {
     int             i, j;
     /* double          ave_wRMSD_from_mean; */
@@ -943,21 +933,21 @@ PrintSuperposStats(CoordsArray *cdsA)
         {
             for (i = 0; i < cnum; ++i)
             {
-                printf("  -> radius of gyration, coords[%3d] = %8.3f \n", i+1, cdsA->coords[i]->radgyr);
+                printf("  -> radius of gyration, cds[%3d] = %8.3f \n", i+1, cdsA->cds[i]->radgyr);
 
                 if (algo->method == 1 || algo->method == 2 || algo->method == 4)
                 {
                     printf(" quaternion rotation eigenvectors \n");
                     printf(" [     w              x              y              z          ]\n");
-                    Mat4Print(cdsA->coords[i]->evecs);
+                    Mat4Print(cdsA->cds[i]->evecs);
                 }
 
                 for (j = 0; j < 4; ++j)
-                    printf("  -> eigenvalue[%d] = %10.3f \n", j, cdsA->coords[i]->evals[j]);
+                    printf("  -> eigenvalue[%d] = %10.3f \n", j, cdsA->cds[i]->evals[j]);
             }
         }
 
-        printf("  -> radius of gyration of mean   %8.3f \n", cdsA->avecoords->radgyr);
+        printf("  -> radius of gyration of mean   %8.3f \n", cdsA->avecds->radgyr);
     }
 
     printf("    %d models superimposed in %.1f ms \n", cnum, algo->milliseconds);
@@ -969,6 +959,7 @@ PrintSuperposStats(CoordsArray *cdsA)
     printf("  * Maximum Likelihood <sigma>                   %10.5f\n", stats->mlRMSD);
     /* printf("\n  * Multipose weighted <RMSD> from the mean      %10.5f * ", stats->wRMSD_from_mean); */
     printf("  ~ Log Likelihood                              %11.2f\n", stats->logL);
+    printf("  ~ Marginal Log Likelihood                     %11.2f\n", stats->mglogl);
     printf("  ~ AIC                                         %11.2f\n", stats->AIC);
     printf("  ~ BIC                                         %11.2f\n", stats->BIC);
     printf("  + Rotational, translational, covar chi^2      %11.2f (P:%3.2e)\n",
@@ -1001,8 +992,6 @@ PrintSuperposStats(CoordsArray *cdsA)
     }
     if (algo->htrans != 0)
         printf("  * Translation normal chi^2      %10.5f\n", stats->htrans_chi2);
-    if (algo->LedoitWolf > 0)
-        printf("  * Ledoit parameters             p1:%9.4f p2:%9.4f\n", stats->ledoit1, stats->ledoit2);
 
     printf("  < skewness                                    %11.2f (P:%3.2e)\n",
            stats->skewness[3], 2.0 * normal_sdf(fabs(stats->skewness[3]/stats->SES), 0.0, 1.0));
@@ -1023,7 +1012,7 @@ PrintSuperposStats(CoordsArray *cdsA)
     printf("  Data pts = %d,  Free params = %d,  D/P = %-5.1f\n",
            (int) stats->ndata, (int) stats->nparams, (stats->ndata / stats->nparams));
 
-    if (algo->jackknife == 0 && algo->reflection == 1)
+    if (algo->reflection == 1)
     {
         CalcANOVAF(cdsA);
         F1 = mysquare(stats->anova_RMSD);
@@ -1056,10 +1045,6 @@ PrintSuperposStats(CoordsArray *cdsA)
         printf("  * Durbin-Watson correlation coeff                 %5.3f\n", 1.0 - stats->dw/2.0);
     }
 
-    if (algo->dimweight != 0)
-        printf("  * Axial variances:                [ %5.3f  %5.3f  %5.3f ]\n",
-               cdsA->AxCovMat[0][0], cdsA->AxCovMat[1][1], cdsA->AxCovMat[2][2]);
-
     printf("  * Median structure = #%d\n", stats->median + 1);
     printf("  N(total) = %d, N(atoms) = %d, N(structures) = %d\n",
            (cnum * vlen), vlen, cnum);
@@ -1311,7 +1296,7 @@ ConvertLele(char *fp_name, const int dim, const int forms, const int lmarks)
 
 
 void
-WriteLeleModelFile(PDBCoordsArray *pdbAr)
+WriteLeleModelFile(PDBCdsArray *pdbAr)
 {
     FILE           *pdbfile = NULL;
     int             i, j;
@@ -1332,9 +1317,9 @@ WriteLeleModelFile(PDBCoordsArray *pdbAr)
         for (j = 0; j < pdbAr->vlen; ++j)
         {
             fprintf(pdbfile, "%.3f\t%.3f\t%.3f\n",
-                    pdbAr->coords[i]->x[j],
-                    pdbAr->coords[i]->y[j],
-                    pdbAr->coords[i]->z[j]);
+                    pdbAr->cds[i]->x[j],
+                    pdbAr->cds[i]->y[j],
+                    pdbAr->cds[i]->z[j]);
         }
     }
 
